@@ -215,7 +215,7 @@ static void _cairo_dock_about (G_GNUC_UNUSED GtkMenuItem *pMenuItem, CairoContai
 	GtkWidget *pVBox = _gtk_vbox_new (0);
 	gtk_box_pack_start (GTK_BOX (pHBox), pVBox, FALSE, FALSE, 0);
 	
-	GtkWidget *pLink = gtk_link_button_new_with_label (CAIRO_DOCK_SITE_URL, "Cairo-Dock (2007-2012)\n version "CAIRO_DOCK_VERSION);
+	GtkWidget *pLink = gtk_link_button_new_with_label (CAIRO_DOCK_SITE_URL, "Cairo-Dock (2007-2013)\n version "CAIRO_DOCK_VERSION);
 	gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
 	
 	//~ pLink = gtk_link_button_new_with_label (CAIRO_DOCK_FORUM_URL, _("Community site"));
@@ -338,8 +338,8 @@ static void _cairo_dock_about (G_GNUC_UNUSED GtkMenuItem *pMenuItem, CairoContai
 	g_free (text);
 	
 	gtk_window_resize (GTK_WINDOW (pDialog),
-		MIN (CAIRO_DOCK_ABOUT_WIDTH, g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]),
-		MIN (CAIRO_DOCK_ABOUT_HEIGHT, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
+		MIN (CAIRO_DOCK_ABOUT_WIDTH, gldi_get_desktop_width()),
+		MIN (CAIRO_DOCK_ABOUT_HEIGHT, gldi_get_desktop_height() - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
 
 	gtk_widget_show_all (pDialog);
 
@@ -584,6 +584,11 @@ static void cairo_dock_add_separator (G_GNUC_UNUSED GtkMenuItem *pMenuItem, gpoi
 	_cairo_dock_create_launcher (icon, pDock, CAIRO_DOCK_DESKTOP_FILE_FOR_SEPARATOR);
 }
 
+static void cairo_dock_add_applet (G_GNUC_UNUSED GtkMenuItem *pMenuItem, G_GNUC_UNUSED gpointer *data)
+{
+	cairo_dock_show_addons ();
+}
+
 static void _add_add_entry (GtkWidget *pMenu, gpointer *data)
 {
 	GtkWidget *pSubMenuAdd = cairo_dock_create_sub_menu (_("Add"), pMenu, GTK_STOCK_ADD);
@@ -596,6 +601,8 @@ static void _add_add_entry (GtkWidget *pMenu, gpointer *data)
 	
 	GtkWidget *pMenuItem = _add_entry_in_menu (_("Custom launcher"), GTK_STOCK_ADD, cairo_dock_add_launcher, pSubMenuAdd);
 	gtk_widget_set_tooltip_text (pMenuItem, _("Usually you would drag a launcher from the menu and drop it on the dock."));
+	
+	_add_entry_in_menu (_("Applet"), GTK_STOCK_ADD, cairo_dock_add_applet, pSubMenuAdd);
 }
 
 
@@ -619,12 +626,14 @@ static void _on_answer_remove_icon (int iClickedButton, G_GNUC_UNUSED GtkWidget
 				if (iClickedButton == 0 || iClickedButton == -1)  // ok button or Enter.
 					bDestroyIcons = FALSE;
 			}
+			CairoDock *pDock = NULL;
+			const gchar *cDockName = NULL;
 			if (!bDestroyIcons)
 			{
-				CairoDock *pDock = CAIRO_DOCK (icon->pContainer);
-				const gchar *cDockName = cairo_dock_search_dock_name (pDock);
-				cairo_dock_remove_icons_from_dock (icon->pSubDock, pDock, cDockName);
+				pDock = CAIRO_DOCK (icon->pContainer);
+				cDockName = cairo_dock_search_dock_name (pDock);
 			}
+			cairo_dock_remove_icons_from_dock (icon->pSubDock, pDock, cDockName);
 			cairo_dock_destroy_dock (icon->pSubDock, (CAIRO_DOCK_IS_APPLI (icon) && icon->cClass != NULL ? icon->cClass : icon->cName));
 			icon->pSubDock = NULL;
 		}
@@ -954,7 +963,7 @@ static void _cairo_dock_set_custom_appli_icon (G_GNUC_UNUSED GtkMenuItem *pMenuI
 				if (pKeyFile != NULL)
 				{
 					g_key_file_set_string (pKeyFile, "TaskBar", "overwrite exception", myTaskbarParam.cOverwriteException);
-					cairo_dock_write_keys_to_file (pKeyFile, g_cConfFile);
+					cairo_dock_write_keys_to_conf_file (pKeyFile, g_cConfFile);
 					
 					g_key_file_free (pKeyFile);
 				}
@@ -1377,6 +1386,17 @@ static void _cairo_dock_change_window_above (G_GNUC_UNUSED GtkMenuItem *pMenuIte
 	}
 }
 
+static void _cairo_dock_change_window_sticky (G_GNUC_UNUSED GtkMenuItem *pMenuItem, gpointer *data)
+{
+	Icon *icon = data[0];
+	// CairoDock *pDock = data[1];
+	if (CAIRO_DOCK_IS_APPLI (icon))
+	{
+		gboolean bIsSticky = cairo_dock_xwindow_is_sticky (icon->Xid);
+		cairo_dock_set_xwindow_sticky (icon->Xid, ! bIsSticky);
+	}
+}
+
 static void _cairo_dock_move_class_to_desktop (G_GNUC_UNUSED GtkMenuItem *pMenuItem, gpointer *user_data)
 {
 	gpointer *data = user_data[0];
@@ -1407,6 +1427,10 @@ static void _add_desktops_entry (GtkWidget *pMenu, gboolean bAll, gpointer *data
 	
 	if (g_desktopGeometry.iNbDesktops > 1 || g_desktopGeometry.iNbViewportX > 1 || g_desktopGeometry.iNbViewportY > 1)
 	{
+		// add separator
+		pMenuItem = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (pMenu), pMenuItem);
+
 		int i, j, k, iDesktopCode;
 		const gchar *cLabel;
 		if (g_desktopGeometry.iNbDesktops > 1 && (g_desktopGeometry.iNbViewportX > 1 || g_desktopGeometry.iNbViewportY > 1))
@@ -1715,27 +1739,14 @@ static gboolean _on_enter_menu_item (GtkWidget* pWidget,
 }
 static GtkWidget *_add_new_button_to_hbox (const gchar *gtkStock, const gchar *cTooltip, GCallback pFunction, GtkWidget *hbox, gpointer data)
 {
-	static GtkCssProvider *css = NULL;
-	if (css == NULL)
-	{
-		css = gtk_css_provider_new ();  // make the buttons as small as possible, or they will be too large for a menu-item.
-		gtk_css_provider_load_from_data (css,
-			".button {\n" \
-			"-GtkButton-default-border : 0px;\n" \
-			"-GtkButton-default-outside-border : 0px;\n" \
-			"-GtkButton-inner-border: 0px;\n" \
-			"border-image-width: 0px;\n" \
-			"border-style: none;\n" \
-			"border-width: 0px;\n" \
-			"box-shadow: none;\n" \
-			"}", -1, NULL);
-	}
-	
 	GtkWidget *pButton = gtk_button_new ();
-	g_object_set (pButton, "width-request", 28, NULL);  // enlarge the button compared to its natural size, to make it easier to click, because a menu-item is quite small (it won't affect the menu width, except for apps with really small displayed name like "geany").
-	GtkStyleContext *ctx = gtk_widget_get_style_context (pButton);
-	gtk_style_context_add_provider (ctx, GTK_STYLE_PROVIDER (css), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	gtk_style_context_add_class (ctx, GTK_STYLE_CLASS_MENU);
+	/*
+		GtkStyleContext *ctx = gtk_widget_get_style_context (pButton);
+	// or we can just remove the style of a button but it's still a button :)
+		gtk_style_context_remove_class (ctx, GTK_STYLE_CLASS_BUTTON);
+	 // a style like a menuitem but it's a button...
+		gtk_style_context_add_class (ctx, GTK_STYLE_CLASS_MENUITEM);
+	*/
 	
 	if (gtkStock)
 	{
@@ -1928,12 +1939,15 @@ gboolean cairo_dock_notification_build_icon_menu (G_GNUC_UNUSED gpointer *pUserD
 		//\_________________________ Other actions
 		GtkWidget *pSubMenuOtherActions = cairo_dock_create_sub_menu (_("Other actions"), menu, NULL);
 
+		// Move
 		pMenuItem = _add_entry_in_menu (_("Move to this desktop"), GTK_STOCK_JUMP_TO, _cairo_dock_move_appli_to_current_desktop, pSubMenuOtherActions);
 		if (pAppli && cairo_dock_appli_is_on_current_desktop (pAppli))
 			gtk_widget_set_sensitive (pMenuItem, FALSE);
-		
+
+		// Fullscreen
 		_add_entry_in_menu (icon->bIsFullScreen ? _("Not Fullscreen") : _("Fullscreen"), icon->bIsFullScreen ? GTK_STOCK_LEAVE_FULLSCREEN : GTK_STOCK_FULLSCREEN, _cairo_dock_set_appli_fullscreen, pSubMenuOtherActions);
-		
+
+		// Below
 		if (! icon->bIsHidden)  // this could be a button in the menu, if we find an icon that doesn't look too much like the "minimise" one
 		{
 			if (myTaskbarParam.iActionOnMiddleClick == 4 && ! CAIRO_DOCK_ICON_TYPE_IS_APPLET (icon))  // lower
@@ -1943,13 +1957,22 @@ gboolean cairo_dock_notification_build_icon_menu (G_GNUC_UNUSED gpointer *pUserD
 			_add_entry_in_menu (cLabel, CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-lower.svg", _cairo_dock_lower_appli, pSubMenuOtherActions);
 			g_free (cLabel);
 		}
-		
+
+		// Above
 		gboolean bIsAbove=FALSE, bIsBelow=FALSE;
 		cairo_dock_xwindow_is_above_or_below (icon->Xid, &bIsAbove, &bIsBelow);
 		_add_entry_in_menu (bIsAbove ? _("Don't keep above") : _("Keep above"), bIsAbove ? GTK_STOCK_GOTO_BOTTOM : GTK_STOCK_GOTO_TOP, _cairo_dock_change_window_above, pSubMenuOtherActions);
-		
+
+		// Sticky
+		gboolean bIsSticky = cairo_dock_xwindow_is_sticky (icon->Xid);
+		_add_entry_in_menu (bIsSticky ? _("Visible only on this desktop") : _("Visible on all desktops"), GTK_STOCK_JUMP_TO, _cairo_dock_change_window_sticky, pSubMenuOtherActions);
+
 		_add_desktops_entry (pSubMenuOtherActions, FALSE, data);
 		
+		// add separator
+		pMenuItem = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (pSubMenuOtherActions), pMenuItem);
+
 		_add_entry_in_menu (_("Kill"), GTK_STOCK_CANCEL, _cairo_dock_kill_appli, pSubMenuOtherActions);
 	}
 	else if (CAIRO_DOCK_IS_MULTI_APPLI (icon))
