@@ -38,6 +38,7 @@
 #include "cairo-dock-desklet-factory.h"
 #include "cairo-dock-dialog-manager.h"
 #include "cairo-dock-dialog-manager.h"
+#include "cairo-dock-themes-manager.h"  // cairo_dock_update_conf_file
 #include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-module-factory.h"
 #include "cairo-dock-log.h"
@@ -69,18 +70,19 @@ static void _cairo_dock_hide_show_in_class_subdock (Icon *icon)
 {
 	if (icon->pSubDock == NULL || icon->pSubDock->icons == NULL)
 		return;
+	// if the appli has the focus, we hide all the windows, else we show them all
 	Icon *pIcon;
 	GList *ic;
 	for (ic = icon->pSubDock->icons; ic != NULL; ic = ic->next)
 	{
 		pIcon = ic->data;
-		if (pIcon->Xid != 0 && ! pIcon->bIsHidden)  // par defaut on cache tout.
+		if (pIcon->Xid != 0 && pIcon->Xid == cairo_dock_get_current_active_window ())
 		{
 			break;
 		}
 	}
 	
-	if (ic != NULL)  // au moins une fenetre est visible, on cache tout.
+	if (ic != NULL)  // one of the windows of the appli has the focus -> hide.
 	{
 		for (ic = icon->pSubDock->icons; ic != NULL; ic = ic->next)
 		{
@@ -100,10 +102,29 @@ static void _cairo_dock_hide_show_in_class_subdock (Icon *icon)
 			if (pIcon->Xid != 0)
 				pZOrderList = g_list_insert_sorted (pZOrderList, pIcon, (GCompareFunc) _compare_zorder);
 		}
+		
+		int iNumDesktop, iViewPortX, iViewPortY;
+		cairo_dock_get_current_desktop_and_viewport (&iNumDesktop, &iViewPortX, &iViewPortY);
+		
 		for (ic = pZOrderList; ic != NULL; ic = ic->next)
 		{
 			pIcon = ic->data;
-			cairo_dock_show_xwindow (pIcon->Xid);
+			if (cairo_dock_appli_is_on_desktop (pIcon, iNumDesktop, iViewPortX, iViewPortY))
+				break;
+		}
+		if (pZOrderList && ic == NULL)  // no window on the current desktop -> take the first desktop
+		{
+			pIcon = pZOrderList->data;
+			iNumDesktop = pIcon->iNumDesktop;
+			iViewPortX = pIcon->iViewPortX;
+			iViewPortY = pIcon->iViewPortY;
+		}
+		
+		for (ic = pZOrderList; ic != NULL; ic = ic->next)
+		{
+			pIcon = ic->data;
+			if (cairo_dock_appli_is_on_desktop (pIcon, iNumDesktop, iViewPortX, iViewPortY))
+				cairo_dock_show_xwindow (pIcon->Xid);
 		}
 		g_list_free (pZOrderList);
 	}
@@ -240,7 +261,8 @@ gboolean cairo_dock_notification_click_icon (G_GNUC_UNUSED gpointer pUserData, I
 	}
 	else if (CAIRO_DOCK_IS_APPLI (icon) && ! CAIRO_DOCK_IS_APPLET (icon))  // icon holding an appli, but not being an applet -> show/hide the window.
 	{
-		if (cairo_dock_get_current_active_window () == icon->Xid && myTaskbarParam.bMinimizeOnClick)  // ne marche que si le dock est une fenêtre de type 'dock', sinon il prend le focus.
+		Icon *pAppli = cairo_dock_get_icon_with_Xid (icon->Xid);
+		if (pAppli && cairo_dock_get_current_active_window () == icon->Xid && myTaskbarParam.bMinimizeOnClick && ! pAppli->bIsHidden && cairo_dock_appli_is_on_current_desktop (pAppli))  // ne marche que si le dock est une fenêtre de type 'dock', sinon il prend le focus.
 			cairo_dock_minimize_xwindow (icon->Xid);
 		else
 			cairo_dock_show_xwindow (icon->Xid);
@@ -430,10 +452,6 @@ void cairo_dock_set_custom_icon_on_appli (const gchar *cFilePath, Icon *icon, Ca
 		cairo_dock_copy_file (cPath?cPath:cFilePath, cDestPath);
 		g_free (cDestPath);
 		g_free (cPath);
-		/**gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s/%s%s\"", cPath?cPath:cFilePath, g_cCurrentIconsPath, icon->cClass, ext);
-		cd_debug (" -> '%s'", cCommand);
-		int r = system (cCommand);
-		g_free (cCommand);*/
 		
 		cairo_dock_reload_icon_image (icon, pContainer);
 		cairo_dock_redraw_icon (icon, pContainer);
