@@ -37,7 +37,7 @@
 **    Karl Lattimer <karl@qdh.org.uk>
 ** Originally conceived as a stress-test for cairo, librsvg, and glitz.
 **
-*********************** VERSION 0.1 and above (2007-2012) *********************
+*********************** VERSION 0.1 and above (2007-2013) *********************
 **
 ** author(s) :
 **     Fabrice Rey <fabounet@glx-dock.org>
@@ -72,13 +72,13 @@
 #include "cairo-dock-log.h"
 #include "cairo-dock-keybinder.h"
 #include "cairo-dock-opengl.h"
+#include "cairo-dock-packages.h"
 #include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command
 #include "cairo-dock-core.h"
 
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-gui-backend.h"
 #include "cairo-dock-user-interaction.h"
-#include "help/cairo-dock-help.h"
 
 //#define CAIRO_DOCK_THEME_SERVER "http://themes.glx-dock.org"
 #define CAIRO_DOCK_THEME_SERVER "http://download.tuxfamily.org/glxdock/themes"
@@ -113,8 +113,21 @@ static gchar *s_cDefaulBackend = NULL;
 static gint s_iGuiMode = 0;  // 0 = simple mode, 1 = advanced mode
 static gint s_iLastYear = 0;
 static gint s_iNbCrashes = 0;
+static gboolean s_bPingServer = TRUE;
 
 
+static void _on_got_server_answer (const gchar *data, G_GNUC_UNUSED gpointer user_data)
+{
+	if (data != NULL)
+	{
+		s_bPingServer = TRUE;  // after we got the answer, we can write in the global file to not try any more.
+		gchar *cConfFilePath = g_strdup_printf ("%s/.cairo-dock", g_cCairoDockDataDir);
+		cairo_dock_update_conf_file (cConfFilePath,
+			G_TYPE_BOOLEAN, "Launch", "ping server", s_bPingServer,
+			G_TYPE_INVALID);
+		g_free (cConfFilePath);
+	}
+}
 static gboolean _cairo_dock_successful_launch (gpointer data)
 {
 	s_bSucessfulLaunch = TRUE;
@@ -140,6 +153,13 @@ static gboolean _cairo_dock_successful_launch (gpointer data)
 		g_free (cMessageFull);
 		g_free (cMessage);
 	}
+	
+	if (! s_bPingServer && g_str_has_suffix (g_cCairoDockDataDir, CAIRO_DOCK_DATA_DIR))  // the server (which hosts themes, third-party applets and packages) has never been accessed yet, ping it once
+	{
+		s_bPingServer = TRUE;
+		cairo_dock_get_url_data_async (CAIRO_DOCK_THEME_SERVER"/ping.txt", (GFunc)_on_got_server_answer, NULL);
+	}
+	
 	return FALSE;
 }
 static gboolean _cairo_dock_first_launch_setup (G_GNUC_UNUSED gpointer data)
@@ -151,6 +171,12 @@ static void _cairo_dock_quit (G_GNUC_UNUSED int signal)
 {
 	gtk_main_quit ();
 }
+/* Crash at startup:
+ *  - First 2 crashes: retry with a delay of 2 sec (maybe due to a problem at startup)
+ *  - 3th crash: remove the applet and restart the dock
+ *  - 4th crash: show the maintenance mode
+ *  - 5th crash: quit
+ */
 static void _cairo_dock_intercept_signal (int signal)
 {
 	cd_warning ("Cairo-Dock has crashed (sig %d).\nIt will be restarted now.\nFeel free to report this bug on glx-dock.org to help improving the dock!", signal);
@@ -176,7 +202,7 @@ static void _cairo_dock_intercept_signal (int signal)
 	{
 		if (s_iNbCrashes < 2)  // the first 2 crashes, restart with a delay (in case we were launched too early on startup).
 			g_string_append (s_pLaunchCommand, " -w 2");  // 2s delay.
-		else if (g_pCurrentModule == NULL)  // several crashes, and no culprit => start in maintenance mode.
+		else if (g_pCurrentModule == NULL || s_iNbCrashes == 3)  // crash and no culprit or 4th crash => start in maintenance mode.
 			g_string_append (s_pLaunchCommand, " -m");
 		g_string_append_printf (s_pLaunchCommand, " -q %d", s_iNbCrashes + 1);  // increment the first-crash counter.
 	}  // else a random crash, respawn quietly.
@@ -224,6 +250,7 @@ static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 		
 		s_iGuiMode = g_key_file_get_integer (pKeyFile, "Gui", "mode", NULL);  // 0 by default
 		s_iLastYear = g_key_file_get_integer (pKeyFile, "Launch", "last year", NULL);  // 0 by default
+		s_bPingServer = g_key_file_get_boolean (pKeyFile, "Launch", "ping server", NULL);  // FALSE by default
 	}
 	else  // first launch or old version, the file doesn't exist yet.
 	{
@@ -281,7 +308,10 @@ int main (int argc, char** argv)
 			g_string_append_printf (s_pLaunchCommand, " %s", argv[i]);
 		}
 	}
-	if (s_iNbCrashes > 3)
+	/* Crash: 5th crash: an applet has already been removed and the maintenance
+	 * mode has already been displayed => stop
+	 */
+	if (s_iNbCrashes > 4)
 	{
 		g_print ("Sorry, Cairo-Dock has encoutered some problems, and will quit.\n");
 		return 1;
@@ -293,7 +323,9 @@ int main (int argc, char** argv)
 	
 	
 	// init lib
+	#if !defined (GLIB_VERSION_2_36) // no longer needed now... (>= 2.35)
 	g_type_init (); // should initialise threads too on new versions of GLIB (>= 2.24)
+	#endif
 	#if (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 24)
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
@@ -588,7 +620,6 @@ int main (int argc, char** argv)
 			cUserDefinedModuleDir = NULL;
 		}
 	}
-	cairo_dock_register_help_module ();  // this applet is made for Cairo-Dock, not gldi; therefore, it's not installed as a separate library, so we manually register it.
 	
 	//\___________________ define GUI backend.
 	cairo_dock_load_user_gui_backend (s_iGuiMode);
@@ -675,20 +706,25 @@ int main (int argc, char** argv)
 	//\___________________ handle crashes.
 	if (! bTesting)
 		_cairo_dock_set_signal_interception ();
+
+	//\___________________ Disable modules that have crashed
+	if (cExcludeModule != NULL && (s_iNbCrashes > 2 || bMaintenance)) // 3th crash or 4th (with -m)
+	{
+		gchar *cCommand = g_strdup_printf ("sed -i \"/modules/ s/%s//g\" \"%s\"",
+			cExcludeModule, g_cConfFile);
+		int r = system (cCommand);
+		if (r < 0)
+			cd_warning ("Not able to launch this command: %s", cCommand);
+		else
+			cd_warning (_("The module '%s' has been deactivated because it may "
+			"have caused some problems.\nYou can reactivate it, if it happens "
+			"again thanks to report it at http://glx-dock.org"), cExcludeModule);
+		g_free (cCommand);
+	}
 	
 	//\___________________ maintenance mode -> show the main config panel.
 	if (bMaintenance)
 	{
-		if (cExcludeModule != NULL)
-		{
-			cd_warning (_("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org"), cExcludeModule);
-			gchar *cCommand = g_strdup_printf ("sed -i \"/modules/ s/%s//g\" \"%s\"", cExcludeModule, g_cConfFile);
-			int r = system (cCommand);
-			if (r < 0)
-				cd_warning ("Not able to launch this command: %s", cCommand);
-			g_free (cCommand);
-		}
-		
 		cairo_dock_load_user_gui_backend (1);  // force the advanced GUI, it can display the config before the theme is loaded.
 		
 		GtkWidget *pWindow = cairo_dock_show_main_gui ();
@@ -727,8 +763,6 @@ int main (int argc, char** argv)
 		if (r < 0)
 			cd_warning ("Not able to launch this command: %s", cCommand);
 		g_free (cCommand);
-		
-		cairo_dock_mark_current_theme_as_modified (FALSE);  // on ne proposera pas de sauvegarder ce theme.
 	}
 	cairo_dock_load_current_theme ();
 	
@@ -755,6 +789,35 @@ int main (int argc, char** argv)
 			G_TYPE_STRING, "Launch", "last version", CAIRO_DOCK_VERSION,
 			G_TYPE_INVALID);
 		g_free (cConfFilePath);
+		
+		if (strcmp (CAIRO_DOCK_VERSION, "3.2.0") == 0 && g_strcmp0 (g_getenv ("DESKTOP_SESSION"), "cairo-dock") == 0)  // from 3.2, Indicator-generic replaces all the indicator applets, and is very helpful if we are on a cairo-dock session.
+		{
+			const gchar *cModuleName = "Indicator-Generic";
+			CairoDockModule *pModule = cairo_dock_find_module_from_name (cModuleName);
+			if (pModule && pModule->pInstancesList == NULL) // it exists but it's not activated
+			{
+				/* copy the .conf file mostly to place the new icons on the
+				 * right place (at least on the second dock) but only if we are
+				 * using a second dock
+				 */
+				gchar *cSecondDockFile = g_strdup_printf ("%s/_MainDock_-2.conf", g_cCurrentThemePath);
+				if (g_file_test (cSecondDockFile, G_FILE_TEST_EXISTS))
+				{
+					gchar *cCommand = g_strdup_printf ("cp -r \"%s/%s\" \"%s/plug-ins/\"",
+						CAIRO_DOCK_SHARE_DATA_DIR"/themes/Default-Panel/plug-ins",
+						cModuleName,
+						g_cCurrentThemePath);
+
+					int r = system (cCommand);
+					if (r < 0)
+						cd_warning ("Not able to launch this command: %s", cCommand);
+					g_free (cCommand);
+				}
+				g_free (cSecondDockFile);
+
+				cairo_dock_activate_module_and_load (cModuleName); // launch it right now
+			}
+		}
 	}
 	
 	//g_print ("bFirstLaunch: %d; bNewVersion: %d\n", bFirstLaunch, bNewVersion);
@@ -788,12 +851,12 @@ int main (int argc, char** argv)
 		// In case something has changed in Compiz/Gtk/others, we also run the script on a new version of the dock.
 		g_timeout_add_seconds (4, _cairo_dock_first_launch_setup, NULL);
 	}
-	else if (cExcludeModule != NULL && ! bMaintenance)
+	else if (cExcludeModule != NULL && ! bMaintenance && s_iNbCrashes > 1)
 	{
 		gchar *cMessage;
-		if (s_iNbCrashes < 2)
+		if (s_iNbCrashes == 2) // <=> second crash: display a dialogue
 			cMessage = g_strdup_printf (_("The module '%s' may have encountered a problem.\nIt has been restored successfully, but if it happens again, please report it at http://glx-dock.org"), cExcludeModule);
-		else
+		else // since the 3th crash: the applet has been disabled
 			cMessage = g_strdup_printf (_("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org"), cExcludeModule);
 		
 		CairoDockModule *pModule = cairo_dock_find_module_from_name (cExcludeModule);
