@@ -251,7 +251,6 @@ void cairo_dock_start_icon_animation (Icon *pIcon, CairoDock *pDock)
 
 void cairo_dock_request_icon_animation (Icon *pIcon, CairoContainer *pContainer, const gchar *cAnimation, int iNbRounds)
 {
-	//g_print ("%s (%s, state:%d)\n", __func__, pIcon->cName, pIcon->iAnimationState);
 	CairoDock *pDock;
 	if (! CAIRO_DOCK_IS_DOCK (pContainer))  // at the moment, only docks can animate their icons
 		return;
@@ -269,10 +268,14 @@ void cairo_dock_request_icon_animation (Icon *pIcon, CairoContainer *pContainer,
 
 void cairo_dock_request_icon_attention (Icon *pIcon, CairoDock *pDock, const gchar *cAnimation, int iNbRounds)
 {
+	// stop any current animation
 	cairo_dock_stop_icon_animation (pIcon);
+	
+	// set the 'attention animation' flag
 	pIcon->bIsDemandingAttention = TRUE;
 	
-	if (iNbRounds <= 0)
+	// start the animation
+	if (iNbRounds <= 0)  // <= 0 means infinite
 		iNbRounds = 1e6;
 	if (cAnimation == NULL || *cAnimation == '\0' || strcmp (cAnimation, "default") == 0)
 	{
@@ -285,7 +288,7 @@ void cairo_dock_request_icon_attention (Icon *pIcon, CairoDock *pDock, const gch
 	cairo_dock_request_icon_animation (pIcon, CAIRO_CONTAINER (pDock), cAnimation, iNbRounds);
 	cairo_dock_mark_icon_as_clicked (pIcon);  // pour eviter qu'un simple survol ne stoppe l'animation.
 	
-	// on reporte la demande d'attention recursivement vers le bas.
+	// if the icon is in a sub-dock, also animate the main icon.
 	if (pDock->iRefCount > 0)
 	{
 		CairoDock *pParentDock = NULL;
@@ -301,6 +304,9 @@ void cairo_dock_request_icon_attention (Icon *pIcon, CairoDock *pDock, const gch
 
 void cairo_dock_stop_icon_attention (Icon *pIcon, CairoDock *pDock)
 {
+	if (! pIcon->bIsDemandingAttention)
+		return;
+	cd_debug ("%s (%s)", __func__, pIcon->cName);
 	cairo_dock_stop_icon_animation (pIcon);
 	//cairo_dock_redraw_icon (pIcon, CAIRO_CONTAINER (pDock));  // a faire avant, lorsque l'icone est encore en mode demande d'attention.
 	pIcon->bIsDemandingAttention = FALSE;
@@ -343,7 +349,6 @@ void cairo_dock_trigger_icon_removal_from_dock (Icon *pIcon)
 			pIcon->fInsertRemoveFactor = 1.0;
 		else
 			pIcon->fInsertRemoveFactor = 0.05;
-		///cairo_dock_notify_on_object (&myDocksMgr, NOTIFICATION_REMOVE_ICON, pIcon, pDock);
 		cairo_dock_notify_on_object (pDock, NOTIFICATION_REMOVE_ICON, pIcon, pDock);
 		cairo_dock_start_icon_animation (pIcon, pDock);
 	}
@@ -422,6 +427,9 @@ gboolean cairo_dock_on_insert_remove_icon_notification (G_GNUC_UNUSED gpointer p
 	if (pIcon->iAnimationState == CAIRO_DOCK_STATE_REMOVE_INSERT)  // already in insert/remove state
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
+	if (pIcon->fInsertRemoveFactor == 0)  // animation not needed.
+		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	
 	cairo_dock_mark_icon_as_inserting_removing (pIcon);  // On prend en charge le dessin de l'icone pendant sa phase d'insertion/suppression.
 	
 	///if (fabs (pIcon->fInsertRemoveFactor) < .1)  // useless or not needed animation.
@@ -470,22 +478,18 @@ static gboolean _cairo_dock_transition_step (G_GNUC_UNUSED gpointer pUserData, I
 				return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 			bContinue = pTransition->render_opengl (pIcon, pTransition->pUserData);
 			cairo_dock_end_draw_icon (pIcon, pContainer);
+			cairo_dock_redraw_icon (pIcon, pContainer);
 		}
 		else if (pTransition->render != NULL)
 		{
 			bContinue = pTransition->render (pIcon, pTransition->pUserData);
-			cairo_dock_update_icon_texture (pIcon);
 		}
 	}
 	else if (pTransition->render != NULL)
 	{
 		bContinue = pTransition->render (pIcon, pTransition->pUserData);
-		/**if (pContainer->bUseReflect)
-			cairo_dock_add_reflection_to_icon (pIcon, pContainer);*/
 	}
 	
-	cairo_dock_redraw_icon (pIcon, pContainer);
-	
 	if (pTransition->iDuration != 0 && pTransition->iElapsedTime >= pTransition->iDuration)
 		bContinue = FALSE;
 	
@@ -539,60 +543,3 @@ void cairo_dock_remove_transition_on_icon (Icon *pIcon)
 	g_free (pTransition);
 	cairo_dock_set_transition (pIcon, NULL);
 }
-
-
-static gboolean _update_busy_animation (CairoOverlay *pOverlay, Icon *pIcon, CairoContainer *pContainer, gboolean *bContinueAnimation)
-{
-	CairoDockImageBuffer *pImage = cairo_dock_get_overlay_image_buffer (pOverlay);
-	if (! cairo_dock_image_buffer_is_animated (pImage))
-		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-	//g_print ("%s ()\n", __func__);
-	
-	cairo_dock_image_buffer_next_frame (pImage);
-	
-	cairo_dock_redraw_icon (pIcon, pContainer);
-	
-	*bContinueAnimation = TRUE;
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-}
-static gboolean _remove_busy_animation (Icon *pIcon, CairoOverlay *pOverlay)
-{
-	//g_print ("%s ()\n", __func__);
-	cairo_dock_remove_notification_func_on_object (pIcon,
-		NOTIFICATION_UPDATE_ICON_SLOW,
-		(CairoDockNotificationFunc) _update_busy_animation,
-		pOverlay);
-	
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-}
-static const gchar *busy_id = "busy-animation";  // unique ID for all the busy-animation overlays.
-void cairo_dock_start_busy_animation (Icon *pIcon)
-{
-	CairoContainer *pContainer = pIcon->pContainer;
-	g_return_if_fail (pContainer != NULL);
-	
-	CairoOverlay *pOverlay = cairo_dock_add_overlay_from_image (pIcon, NULL, CAIRO_OVERLAY_MIDDLE, (gpointer)busy_id);  // remove any previous busy-animation overlay
-	CairoDockImageBuffer *pImage = cairo_dock_get_overlay_image_buffer (pOverlay);
-	
-	int iWidth, iHeight;
-	cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
-	cairo_dock_load_image_buffer_full (pImage, "/usr/share/cairo-dock/plug-ins/Cairo-Penguin/themes/Classic/faller.png", iWidth * pOverlay->fScale, iHeight * pOverlay->fScale, CAIRO_DOCK_ANIMATED_IMAGE, 1.);
-	
-	
-	cairo_dock_register_notification_on_object (pIcon,
-		NOTIFICATION_UPDATE_ICON_SLOW,
-		(CairoDockNotificationFunc) _update_busy_animation,
-		CAIRO_DOCK_RUN_AFTER, pOverlay);
-	
-	cairo_dock_register_notification_on_object (pOverlay,
-		NOTIFICATION_DESTROY,
-		(CairoDockNotificationFunc) _remove_busy_animation,
-		CAIRO_DOCK_RUN_AFTER, pIcon);  // the overlay is tied to the icon, so pIcon stays alive longer than pOverlay
-	
-	cairo_dock_launch_animation (pContainer);
-}
-
-void cairo_dock_stop_busy_animation (Icon *pIcon)
-{
-	cairo_dock_remove_overlay_at_position (pIcon, CAIRO_OVERLAY_MIDDLE, (gpointer)busy_id);
-}
