@@ -43,17 +43,15 @@
 #include "cairo-dock-application-facility.h"
 
 extern CairoDock *g_pMainDock;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern CairoDockHidingEffect *g_pHidingBackend;  // cairo_dock_is_hidden
 extern CairoContainer *g_pPrimaryContainer;
 
-static void _cairo_dock_appli_demands_attention (Icon *icon, CairoDock *pDock, gboolean bForceDemand, Icon *pHiddenIcon)
+static void _cairo_dock_appli_demands_attention (Icon *icon, CairoDock *pDock, gboolean bForceDemand, Icon *pHiddenIcon, CairoAppliAttentionFlag flag)
 {
 	cd_debug ("%s (%s, force:%d)", __func__, icon->cName, bForceDemand);
 	if (CAIRO_DOCK_IS_APPLET (icon))  // on considere qu'une applet prenant le controle d'une icone d'appli dispose de bien meilleurs moyens pour interagir avec l'appli que la barre des taches.
 		return ;
-	if (! pHiddenIcon)
-		icon->bIsDemandingAttention = TRUE;
+	icon->iDemandsAttention |= flag;
 	//\____________________ On montre le dialogue.
 	if (myTaskbarParam.bDemandsAttentionWithDialog)
 	{
@@ -66,7 +64,7 @@ static void _cairo_dock_appli_demands_attention (Icon *icon, CairoDock *pDock, g
 		{
 			pDialog = cairo_dock_show_temporary_dialog (pHiddenIcon->cName, icon, CAIRO_CONTAINER (pDock), 1000*myTaskbarParam.iDialogDuration); // mieux vaut montrer pas d'icone dans le dialogue que de montrer une icone qui n'a pas de rapport avec l'appli demandant l'attention.
 			g_return_if_fail (pDialog != NULL);
-			cairo_dock_set_new_dialog_icon_surface (pDialog, pHiddenIcon->pIconBuffer, pDialog->iIconSize);
+			cairo_dock_set_new_dialog_icon_surface (pDialog, pHiddenIcon->image.pSurface, pDialog->iIconSize);
 		}
 		if (pDialog && bForceDemand)
 		{
@@ -97,26 +95,28 @@ static void _cairo_dock_appli_demands_attention (Icon *icon, CairoDock *pDock, g
 			if (pParentDock)
 				cairo_dock_show_subdock (pPointedIcon, pParentDock);
 		}*/
-		cairo_dock_request_icon_animation (icon, CAIRO_CONTAINER (pDock), myTaskbarParam.cAnimationOnDemandsAttention, 10000);  // animation de 2-3 heures.
+		cairo_dock_request_icon_attention (icon, pDock, myTaskbarParam.cAnimationOnDemandsAttention, 10000);  // animation de 2-3 heures.
 		cairo_dock_launch_animation (CAIRO_CONTAINER (pDock));  // dans le au cas ou le dock ne serait pas encore visible, la fonction precedente n'a pas lance l'animation.
 	}
 	
 	// notify everybody
 	cairo_dock_notify_on_object (&myTaskbarMgr, NOTIFICATION_APPLI_ATTENTION_CHANGED, pHiddenIcon?pHiddenIcon:icon, TRUE);
 }
-void cairo_dock_appli_demands_attention (Icon *icon)
+void cairo_dock_appli_demands_attention (Icon *icon, CairoAppliAttentionFlag flag)
 {
-	cd_debug ("%s (%s / %s , %d)", __func__, icon->cName, icon->cLastAttentionDemand, icon->bIsDemandingAttention);
+	cd_debug ("%s (%s / %s , %d, %s)", __func__, icon->cName, icon->cLastAttentionDemand, icon->iDemandsAttention, icon->cParentDockName);
 	if (icon->Xid == cairo_dock_get_current_active_window ())  // apparemment ce cas existe, et conduit a ne pas pouvoir stopper l'animation de demande d'attention facilement.
 	{
 		cd_message ("cette fenetre a deja le focus, elle ne peut demander l'attention en plus.");
 		return ;
 	}
-	if (icon->bIsDemandingAttention  // already demanding attention
+	if (icon->iDemandsAttention != 0  // already demanding attention
 	&& icon->cLastAttentionDemand && icon->cName && strcmp (icon->cLastAttentionDemand, icon->cName) == 0)  // and message has not changed between the 2 demands.
 	{
+		icon->iDemandsAttention |= flag;
 		return ;
 	}
+	icon->iDemandsAttention |= flag;
 	g_free (icon->cLastAttentionDemand);
 	icon->cLastAttentionDemand = g_strdup (icon->cName);
 	
@@ -124,23 +124,22 @@ void cairo_dock_appli_demands_attention (Icon *icon)
 	CairoDock *pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 	if (pParentDock == NULL)  // appli inhibee ou non affichee.
 	{
-		icon->bIsDemandingAttention = TRUE;  // on met a TRUE meme si ce n'est pas reellement elle qui va prendre la demande.
 		Icon *pInhibitorIcon = cairo_dock_get_inhibitor (icon, TRUE);  // on cherche son inhibiteur dans un dock.
 		if (pInhibitorIcon != NULL)  // appli inhibee.
 		{
 			pParentDock = cairo_dock_search_dock_from_name (pInhibitorIcon->cParentDockName);
 			if (pParentDock != NULL)
-				_cairo_dock_appli_demands_attention (pInhibitorIcon, pParentDock, bForceDemand, NULL);
+				_cairo_dock_appli_demands_attention (pInhibitorIcon, pParentDock, bForceDemand, NULL, flag);
 		}
 		else if (bForceDemand)  // appli pas affichee, mais on veut tout de meme etre notifie.
 		{
 			Icon *pOneIcon = cairo_dock_get_dialogless_icon ();  // on prend une icone dans le main dock.
 			if (pOneIcon != NULL)
-				_cairo_dock_appli_demands_attention (pOneIcon, g_pMainDock, bForceDemand, icon);
+				_cairo_dock_appli_demands_attention (pOneIcon, g_pMainDock, bForceDemand, icon, flag);
 		}
 	}
 	else  // appli dans un dock.
-		_cairo_dock_appli_demands_attention (icon, pParentDock, bForceDemand, NULL);
+		_cairo_dock_appli_demands_attention (icon, pParentDock, bForceDemand, NULL, flag);
 }
 
 static void _cairo_dock_appli_stops_demanding_attention (Icon *icon, CairoDock *pDock)
@@ -151,22 +150,24 @@ static void _cairo_dock_appli_stops_demanding_attention (Icon *icon, CairoDock *
 		cairo_dock_remove_dialog_if_any (icon);
 	if (myTaskbarParam.cAnimationOnDemandsAttention)
 	{
-		cairo_dock_stop_icon_animation (icon);  // arrete l'animation precedemment lancee par la demande.
+		cairo_dock_stop_icon_attention (icon, pDock);  // arrete l'animation precedemment lancee par la demande.
 		gtk_widget_queue_draw (pDock->container.pWidget);  // optimisation possible : ne redessiner que l'icone en tenant compte de la zone de sa derniere animation (pulse ou rebond).
 	}
-	icon->bIsDemandingAttention = FALSE;
+	icon->iDemandsAttention = 0;
 	if (pDock->iRefCount == 0 && pDock->iVisibility == CAIRO_DOCK_VISI_KEEP_BELOW && ! pDock->bIsBelow && ! pDock->container.bInside)
 		cairo_dock_pop_down (pDock);
 	
 	// notify everybody
 	cairo_dock_notify_on_object (&myTaskbarMgr, NOTIFICATION_APPLI_ATTENTION_CHANGED, icon, FALSE);
 }
-void cairo_dock_appli_stops_demanding_attention (Icon *icon)
+void cairo_dock_appli_stops_demanding_attention (Icon *icon, CairoAppliAttentionFlag flag)
 {
+	icon->iDemandsAttention &= (~flag);
+	if (icon->iDemandsAttention != 0)
+		return;
 	CairoDock *pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 	if (pParentDock == NULL)
 	{
-		icon->bIsDemandingAttention = FALSE;  // idem que plus haut.
 		Icon *pInhibitorIcon = cairo_dock_get_inhibitor (icon, TRUE);
 		if (pInhibitorIcon != NULL)
 		{
@@ -241,9 +242,8 @@ gboolean cairo_dock_appli_covers_dock (Icon *pIcon, CairoDock *pDock)
 	return FALSE;
 }
 
-gboolean cairo_dock_appli_overlaps_dock (Icon *pIcon, CairoDock *pDock)
+gboolean cairo_dock_window_overlaps_dock (GtkAllocation *pWindowGeometry, gboolean bIsHidden, CairoDock *pDock)
 {
-	GtkAllocation *pWindowGeometry = &pIcon->windowGeometry;
 	if (pWindowGeometry->width != 0 && pWindowGeometry->height != 0)
 	{
 		int iDockX, iDockY, iDockWidth, iDockHeight;
@@ -262,7 +262,7 @@ gboolean cairo_dock_appli_overlaps_dock (Icon *pIcon, CairoDock *pDock)
 			iDockY = pDock->container.iWindowPositionX + (pDock->container.iWidth - iDockHeight)/2;
 		}
 		
-		if (! pIcon->bIsHidden && pWindowGeometry->x < iDockX + iDockWidth && pWindowGeometry->x + pWindowGeometry->width > iDockX && pWindowGeometry->y < iDockY + iDockHeight && pWindowGeometry->y + pWindowGeometry->height > iDockY)
+		if (! bIsHidden && pWindowGeometry->x < iDockX + iDockWidth && pWindowGeometry->x + pWindowGeometry->width > iDockX && pWindowGeometry->y < iDockY + iDockHeight && pWindowGeometry->y + pWindowGeometry->height > iDockY)
 		{
 			return TRUE;
 		}
@@ -274,34 +274,42 @@ gboolean cairo_dock_appli_overlaps_dock (Icon *pIcon, CairoDock *pDock)
 	return FALSE;
 }
 
+gboolean cairo_dock_appli_overlaps_dock (Icon *pIcon, CairoDock *pDock)
+{
+	return cairo_dock_window_overlaps_dock (&pIcon->windowGeometry, pIcon->bIsHidden, pDock);
+}
+
 
 static void _load_class_icon (Icon *icon)
 {
-	int iWidth = icon->iImageWidth;
-	int iHeight = icon->iImageHeight;
+	int iWidth = icon->iAllocatedWidth;
+	int iHeight = icon->iAllocatedWidth;
+	cairo_surface_t *pSurface = NULL;
 	if (icon->pSubDock != NULL && !myIndicatorsParam.bUseClassIndic)  // icone de sous-dock avec un rendu specifique, on le redessinera lorsque les icones du sous-dock auront ete chargees.
 	{
-		icon->pIconBuffer = cairo_dock_create_blank_surface (iWidth, iHeight);
+		pSurface = cairo_dock_create_blank_surface (iWidth, iHeight);
 	}
 	else
 	{
-		//g_print ("%s (%dx%d)\n", __func__, iWidth, iHeight);
-		icon->pIconBuffer = cairo_dock_create_surface_from_class (icon->cClass,
+		cd_debug ("%s (%dx%d)", __func__, iWidth, iHeight);
+		pSurface = cairo_dock_create_surface_from_class (icon->cClass,
 			iWidth,
 			iHeight);
-		if (icon->pIconBuffer == NULL)  // aucun inhibiteur ou aucune image correspondant a cette classe, on cherche a copier une des icones d'appli de cette classe.
+		if (pSurface == NULL)  // aucun inhibiteur ou aucune image correspondant a cette classe, on cherche a copier une des icones d'appli de cette classe.
 		{
 			const GList *pApplis = cairo_dock_list_existing_appli_with_class (icon->cClass);
 			if (pApplis != NULL)
 			{
 				Icon *pOneIcon = (Icon *) (g_list_last ((GList*)pApplis)->data);  // on prend le dernier car les applis sont inserees a l'envers, et on veut avoir celle qui etait deja present dans le dock (pour 2 raison : continuite, et la nouvelle (en 1ere position) n'est pas forcement deja dans un dock, ce qui fausse le ratio).
-				//g_print ("  load from %s (%dx%d)\n", pOneIcon->cName, iWidth, iHeight);
-				icon->pIconBuffer = cairo_dock_duplicate_inhibitor_surface_for_appli (pOneIcon,
+				cd_debug ("  load from %s (%dx%d)", pOneIcon->cName, iWidth, iHeight);
+				pSurface = cairo_dock_duplicate_inhibitor_surface_for_appli (pOneIcon,
 					iWidth,
 					iHeight);
 			}
 		}
 	}
+	
+	cairo_dock_load_image_buffer_from_surface (&icon->image, pSurface, iWidth, iHeight);
 }
 static Icon *cairo_dock_create_icon_for_class_subdock (Icon *pSameClassIcon, CairoDock *pClassDock)
 {
@@ -509,7 +517,7 @@ void  cairo_dock_set_one_icon_geometry_for_window_manager (Icon *icon, CairoDock
 	iY = y_icon_geometry (icon, pDock);  // il faudrait un fYAtRest ...
 	//g_print (" -> %d;%d (%.2f)\n", iX - pDock->container.iWindowPositionX, iY - pDock->container.iWindowPositionY, icon->fXAtRest);
 	iWidth = icon->fWidth;
-	int dh = (icon->iImageHeight - icon->fHeight);
+	int dh = (icon->image.iWidth - icon->fHeight);
 	iHeight = icon->fHeight + 2 * dh;  // on elargit en haut et en bas, pour gerer les cas ou l'icone grossirait vers le haut ou vers le bas.
 	
 	if (pDock->container.bIsHorizontal)
@@ -535,7 +543,7 @@ void cairo_dock_reserve_one_icon_geometry_for_window_manager (G_GNUC_UNUSED Wind
 				x = x_icon_geometry (pClassmate, pClassmateDock);
 				if (cairo_dock_is_hidden (pMainDock))
 				{
-					y = (pClassmateDock->container.bDirectionUp ? 0 : g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+					y = (pClassmateDock->container.bDirectionUp ? 0 : gldi_get_desktop_height());
 				}
 				else
 				{
@@ -547,7 +555,7 @@ void cairo_dock_reserve_one_icon_geometry_for_window_manager (G_GNUC_UNUSED Wind
 				x = x_icon_geometry (pClassmate, pClassmateDock) + pClassmate->fWidth/2;
 				if (cairo_dock_is_hidden (pClassmateDock))
 				{
-					y = (pClassmateDock->container.bDirectionUp ? 0 : g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+					y = (pClassmateDock->container.bDirectionUp ? 0 : gldi_get_desktop_height());
 				}
 				else
 				{
@@ -575,7 +583,7 @@ void cairo_dock_reserve_one_icon_geometry_for_window_manager (G_GNUC_UNUSED Wind
 					x = x_icon_geometry (pLastLauncher, pMainDock) + pLastLauncher->fWidth/2;
 					if (cairo_dock_is_hidden (pMainDock))
 					{
-						y = (pMainDock->container.bDirectionUp ? 0 : g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+						y = (pMainDock->container.bDirectionUp ? 0 : gldi_get_desktop_height());
 					}
 					else
 					{
@@ -587,7 +595,7 @@ void cairo_dock_reserve_one_icon_geometry_for_window_manager (G_GNUC_UNUSED Wind
 					x = pMainDock->container.iWindowPositionX + 0 + (pMainDock->container.iWidth - pMainDock->fFlatDockWidth) / 2;
 					if (cairo_dock_is_hidden (pMainDock))
 					{
-						y = (pMainDock->container.bDirectionUp ? 0 : g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+						y = (pMainDock->container.bDirectionUp ? 0 : gldi_get_desktop_height());
 					}
 					else
 					{
@@ -615,45 +623,49 @@ gboolean cairo_dock_appli_is_on_desktop (Icon *pIcon, int iNumDesktop, int iNumV
 {
 	// On calcule les coordonnees en repere absolu.
 	int x = pIcon->windowGeometry.x;  // par rapport au viewport courant.
-	x += g_desktopGeometry.iCurrentViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];  // repere absolu
+	x += g_desktopGeometry.iCurrentViewportX * gldi_get_desktop_width();  // repere absolu
 	if (x < 0)
-		x += g_desktopGeometry.iNbViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
+		x += g_desktopGeometry.iNbViewportX * gldi_get_desktop_width();
 	int y = pIcon->windowGeometry.y;
-	y += g_desktopGeometry.iCurrentViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+	y += g_desktopGeometry.iCurrentViewportY * gldi_get_desktop_height();
 	if (y < 0)
-		y += g_desktopGeometry.iNbViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+		y += g_desktopGeometry.iNbViewportY * gldi_get_desktop_height();
 	int w = pIcon->windowGeometry.width, h = pIcon->windowGeometry.height;
 	
 	// test d'intersection avec le viewport donne.
 	return ((pIcon->iNumDesktop == -1 || pIcon->iNumDesktop == iNumDesktop) &&
-		x + w > iNumViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] &&
-		x < (iNumViewportX + 1) * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] &&
-		y + h > iNumViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] &&
-		y < (iNumViewportY + 1) * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+		x + w > iNumViewportX * gldi_get_desktop_width() &&
+		x < (iNumViewportX + 1) * gldi_get_desktop_width() &&
+		y + h > iNumViewportY * gldi_get_desktop_height() &&
+		y < (iNumViewportY + 1) * gldi_get_desktop_height());
+}
+
+gboolean cairo_dock_window_is_on_current_desktop (GtkAllocation *pWindowGeometry, int iWindowDesktopNumber)
+{
+	int iGlobalPositionX, iGlobalPositionY, iWidthExtent, iHeightExtent;  // coordonnees du coin haut gauche dans le referentiel du viewport actuel.
+	iGlobalPositionX = pWindowGeometry->x;
+	iGlobalPositionY = pWindowGeometry->y;
+	iWidthExtent = pWindowGeometry->width;
+	iHeightExtent = pWindowGeometry->height;
+	
+	return ( (iWindowDesktopNumber == g_desktopGeometry.iCurrentDesktop || iWindowDesktopNumber == -1) &&
+		iGlobalPositionX + iWidthExtent > 0 &&
+		iGlobalPositionX < gldi_get_desktop_width() &&
+		iGlobalPositionY + iHeightExtent > 0 &&
+		iGlobalPositionY < gldi_get_desktop_height() );  // -1 <=> 0xFFFFFFFF en unsigned.
 }
 
 gboolean cairo_dock_appli_is_on_current_desktop (Icon *pIcon)
 {
-	int iWindowDesktopNumber, iGlobalPositionX, iGlobalPositionY, iWidthExtent, iHeightExtent;  // coordonnees du coin haut gauche dans le referentiel du viewport actuel.
-	iWindowDesktopNumber = pIcon->iNumDesktop;
-	iGlobalPositionX = pIcon->windowGeometry.x;
-	iGlobalPositionY = pIcon->windowGeometry.y;
-	iWidthExtent = pIcon->windowGeometry.width;
-	iHeightExtent = pIcon->windowGeometry.height;
-	
-	return ( (iWindowDesktopNumber == g_desktopGeometry.iCurrentDesktop || iWindowDesktopNumber == -1) &&
-		iGlobalPositionX + iWidthExtent > 0 &&
-		iGlobalPositionX < g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] &&
-		iGlobalPositionY + iHeightExtent > 0 &&
-		iGlobalPositionY < g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] );  // -1 <=> 0xFFFFFFFF en unsigned.
+	return cairo_dock_window_is_on_current_desktop (&pIcon->windowGeometry, pIcon->iNumDesktop);
 }
 
 void cairo_dock_move_window_to_desktop (Icon *pIcon, int iNumDesktop, int iNumViewportX, int iNumViewportY)
 {
 	cairo_dock_move_xwindow_to_nth_desktop (pIcon->Xid,
 		iNumDesktop,
-		(iNumViewportX - g_desktopGeometry.iCurrentViewportX) * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL],
-		(iNumViewportY - g_desktopGeometry.iCurrentViewportY) * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+		(iNumViewportX - g_desktopGeometry.iCurrentViewportX) * gldi_get_desktop_width(),
+		(iNumViewportY - g_desktopGeometry.iCurrentViewportY) * gldi_get_desktop_height());
 }
 
 void cairo_dock_move_window_to_current_desktop (Icon *pIcon)
@@ -669,43 +681,43 @@ const CairoDockImageBuffer *cairo_dock_appli_get_image_buffer (Icon *pIcon)
 {
 	static CairoDockImageBuffer image;
 	
-	if (pIcon->pIconBuffer == NULL)
+	// if the given icon is not loaded
+	if (pIcon->image.pSurface == NULL)
 	{
+		// try to get the image from the class
 		const CairoDockImageBuffer *pImageBuffer = cairo_dock_get_class_image_buffer (pIcon->cClass);
 		if (pImageBuffer && pImageBuffer->pSurface)
 		{
-			memcpy (&image, pImageBuffer, sizeof (CairoDockImageBuffer));
-			return &image;
-		}
-	}
-	if (pIcon->pIconBuffer == NULL && g_pMainDock)
-	{
-		// set a size (we could set any size, but let's set something useful: if the icon is inserted in a dock and is already loaded at the correct size, it won't be loaded again).
-		gboolean bNoContainer = FALSE;
-		if (pIcon->pContainer == NULL)  // not in a container (=> no size) -> set a size before loading it.
-		{
-			bNoContainer = TRUE;
-			cairo_dock_set_icon_container (pIcon, g_pPrimaryContainer);
-			pIcon->fWidth = pIcon->fHeight = 0;  // no request
-			pIcon->iImageWidth = pIcon->iImageHeight = 0;
-			cairo_dock_set_icon_size_in_dock (g_pMainDock, pIcon);
+			return pImageBuffer;
 		}
 		
-		// load the icon
-		cairo_dock_load_icon_image (pIcon, g_pPrimaryContainer);
-		if (bNoContainer)
+		// try to load the icon.
+		if (g_pMainDock)
 		{
-			cairo_dock_set_icon_container (pIcon, NULL);
+			// set a size (we could set any size, but let's set something useful: if the icon is inserted in a dock and is already loaded at the correct size, it won't be loaded again).
+			gboolean bNoContainer = FALSE;
+			if (pIcon->pContainer == NULL)  // not in a container (=> no size) -> set a size before loading it.
+			{
+				bNoContainer = TRUE;
+				cairo_dock_set_icon_container (pIcon, g_pPrimaryContainer);
+				pIcon->fWidth = pIcon->fHeight = 0;  /// useful ?...
+				pIcon->iRequestedWidth = pIcon->iRequestedHeight = 0;  // no request
+				cairo_dock_set_icon_size_in_dock (g_pMainDock, pIcon);
+			}
+
+			// load the icon
+			cairo_dock_load_icon_image (pIcon, g_pPrimaryContainer);
+			if (bNoContainer)
+			{
+				cairo_dock_set_icon_container (pIcon, NULL);
+			}
 		}
 	}
-	if (pIcon->pIconBuffer != NULL || pIcon->iIconTexture != 0)
+	
+	// if the given icon is loaded, use its image.
+	if (pIcon->image.pSurface != NULL || pIcon->image.iTexture != 0)
 	{
-		int iWidth, iHeight;
-		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
-		image.pSurface = pIcon->pIconBuffer;  // since we got the texture with the load(), we don't use the image buffer constructor.
-		image.iWidth = iWidth;
-		image.iHeight = iHeight;
-		image.iTexture = pIcon->iIconTexture;
+		memcpy (&image, &pIcon->image, sizeof (CairoDockImageBuffer));
 		return &image;
 	}
 	else
