@@ -25,6 +25,7 @@
 #include <signal.h>
 
 #include <cairo.h>
+#include <cairo-xlib.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
@@ -65,7 +66,6 @@ CairoTaskbarManager myTaskbarMgr;
 
 // dependancies
 extern CairoDock *g_pMainDock;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern gboolean g_bUseOpenGL;
 //extern int g_iDamageEvent;
 
@@ -86,7 +86,7 @@ static Atom s_aNetWmIcon;
 static Atom s_aWmHints;
 
 static void cairo_dock_blacklist_appli (Window Xid);
-static Icon * cairo_dock_create_icon_from_xwindow (Window Xid, CairoDock *pDock);
+static Icon * cairo_dock_create_icon_from_xwindow (Window Xid);
 
 
   //////////////////////////
@@ -210,18 +210,39 @@ static void _unhide_all_docks (CairoDock *pDock, G_GNUC_UNUSED Icon *icon)
 
 static void _hide_show_if_on_our_way (CairoDock *pDock, Icon *icon)
 {
-	if (pDock->iVisibility != CAIRO_DOCK_VISI_AUTO_HIDE_ON_OVERLAP && ! myDocksParam.bAutoHideOnFullScreen)
+	if (pDock->iVisibility != CAIRO_DOCK_VISI_AUTO_HIDE_ON_OVERLAP)
 		return ;
-	if (_cairo_dock_appli_is_on_our_way (icon, pDock))  // la nouvelle fenetre active nous gene.
+
+	// maybe we have a window without icon in the dock...
+	GtkAllocation *pWindowGeometry;
+	if (icon != NULL && s_iCurrentActiveWindow != icon->Xid
+		&& s_iCurrentActiveWindow != 0)
+	{
+		pWindowGeometry = g_new (GtkAllocation, 1);
+		cairo_dock_get_xwindow_geometry (s_iCurrentActiveWindow,
+			&pWindowGeometry->x, &pWindowGeometry->y,
+			&pWindowGeometry->width, &pWindowGeometry->height);
+	}
+	else
+		pWindowGeometry = NULL;
+
+	/* hide the dock if the active window or its parent if this window doesn't
+	 * have any dedicated icon in the dock -> If my window's text editor is
+	 * maximised and then I open a 'Search' box, the dock should not appear
+	 * above the maximised window
+	 */
+	if (_cairo_dock_appli_is_on_our_way (icon, pDock) // the new active window is above the dock
+		|| (pWindowGeometry // it's maybe a window without icon. Its parent is not above the dock but maybe this window is above.
+			&& cairo_dock_window_is_on_current_desktop (pWindowGeometry, cairo_dock_get_xwindow_desktop (s_iCurrentActiveWindow))
+			&& cairo_dock_window_overlaps_dock (pWindowGeometry, FALSE, pDock))) // or its parent
 	{
 		if (!cairo_dock_is_temporary_hidden (pDock))
 			cairo_dock_activate_temporary_auto_hide (pDock);
 	}
-	else if (pDock->iVisibility != CAIRO_DOCK_VISI_AUTO_HIDE_ON_OVERLAP_ANY)
-	{
-		if (cairo_dock_is_temporary_hidden (pDock))
-			cairo_dock_deactivate_temporary_auto_hide (pDock);
-	}
+	else if (cairo_dock_is_temporary_hidden (pDock))
+		cairo_dock_deactivate_temporary_auto_hide (pDock);
+
+	g_free (pWindowGeometry);
 }
 
 void cairo_dock_hide_show_if_current_window_is_on_our_way (CairoDock *pDock)
@@ -251,6 +272,9 @@ static gboolean _cairo_dock_remove_old_applis (Window *Xid, Icon *icon, gpointer
 			// notify everybody
 			cairo_dock_notify_on_object (&myTaskbarMgr, NOTIFICATION_APPLI_DESTROYED, icon);
 			
+			if (icon->iDemandsAttention != 0)  // force the stop demanding attention, in case the icon was in a sub-dock (the main icon is also animating).
+				cairo_dock_appli_stops_demanding_attention (icon, CAIRO_APPLI_DEMANDS_ATTENTION | CAIRO_APPLI_URGENCY_HINT);
+			
 			CairoDock *pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 			if (pParentDock != NULL)
 			{
@@ -302,7 +326,7 @@ static void _on_update_applis_list (CairoDock *pDock)
 		if (! bAppliAlreadyRegistered)
 		{
 			cd_message (" cette fenetre (%ld) de la pile n'est pas dans la liste", Xid);
-			icon = cairo_dock_create_icon_from_xwindow (Xid, pDock);
+			icon = cairo_dock_create_icon_from_xwindow (Xid);
 			if (icon != NULL)
 			{
 				icon->iLastCheckTime = s_iTime;
@@ -345,8 +369,8 @@ static gboolean _on_change_active_window_notification (G_GNUC_UNUSED gpointer da
 		CairoDock *pParentDock = NULL;
 		if (CAIRO_DOCK_IS_APPLI (icon))
 		{
-			///if (icon->bIsDemandingAttention)  // on force ici, car il semble qu'on ne recoive pas toujours le retour a la normale.
-			///	cairo_dock_appli_stops_demanding_attention (icon);
+			if (icon->iDemandsAttention != 0)  // force the stop demanding attention, as it can happen (for some reason) that the attention state doesn't change when the appli takes the focus.
+				cairo_dock_appli_stops_demanding_attention (icon, CAIRO_APPLI_DEMANDS_ATTENTION | CAIRO_APPLI_URGENCY_HINT);
 			
 			pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 			if (pParentDock == NULL)  // elle est soit inhibee, soit pas dans un dock.
@@ -406,13 +430,11 @@ static gboolean _on_change_active_window_notification (G_GNUC_UNUSED gpointer da
 
 static gboolean _on_change_current_desktop_viewport_notification (G_GNUC_UNUSED gpointer data)
 {
-	CairoDock *pDock = g_pMainDock;
-	
 	cd_debug ("*** applis du bureau seulement...");
 	// applis du bureau courant seulement.
 	if (myTaskbarParam.bAppliOnCurrentDesktopOnly && myTaskbarParam.bShowAppli)
 	{
-		g_hash_table_foreach (s_hXWindowTable, (GHFunc) _cairo_dock_hide_show_windows_on_other_desktops, pDock);
+		g_hash_table_foreach (s_hXWindowTable, (GHFunc) _cairo_dock_hide_show_windows_on_other_desktops, g_pMainDock);
 	}
 	
 	// visibilite
@@ -443,18 +465,18 @@ static void _on_change_window_state (Icon *icon)
 	// _NET_WM_STATE_DEMANDS_ATTENTION indicates that some action in or with the window happened. For example, it may be set by the Window Manager if the window requested activation but the Window Manager refused it, or the application may set it if it finished some work. This state may be set by both the Client and the Window Manager. It should be unset by the Window Manager when it decides the window got the required attention (usually, that it got activated)."
 	if (bDemandsAttention)
 	{
-		cd_debug ("%s demande votre attention %s !", icon->cName, icon->bIsDemandingAttention?"encore une fois":"");
-		if (! icon->bIsDemandingAttention && (myTaskbarParam.bDemandsAttentionWithDialog || myTaskbarParam.cAnimationOnDemandsAttention))  // some WM tend to abuse this state, so we only acknowledge it if it's not already set.
+		cd_debug ("%s demande votre attention %s !", icon->cName, icon->iDemandsAttention?"encore une fois":"");
+		if (! (icon->iDemandsAttention & CAIRO_APPLI_DEMANDS_ATTENTION) && (myTaskbarParam.bDemandsAttentionWithDialog || myTaskbarParam.cAnimationOnDemandsAttention))  // some WM tend to abuse this state, so we only acknowledge it if it's not already set.
 		{
-			cairo_dock_appli_demands_attention (icon);
+			cairo_dock_appli_demands_attention (icon, CAIRO_APPLI_DEMANDS_ATTENTION);
 		}
 	}
 	else
 	{
-		if (icon->bIsDemandingAttention)
+		if (icon->iDemandsAttention & CAIRO_APPLI_DEMANDS_ATTENTION)
 		{
 			cd_debug ("%s se tait", icon->cName);
-			cairo_dock_appli_stops_demanding_attention (icon);
+			cairo_dock_appli_stops_demanding_attention (icon, CAIRO_APPLI_DEMANDS_ATTENTION);
 		}
 	}
 	
@@ -542,7 +564,7 @@ static void _on_change_window_state (Icon *icon)
 				cd_message ("new backing pixmap (bis) : %d", icon->iBackingPixmap);
 			}
 			// on redessine avec ou sans la miniature, suivant le nouvel etat.
-			cairo_dock_reload_icon_image (icon, CAIRO_CONTAINER (pParentDock));
+			cairo_dock_load_icon_image (icon, CAIRO_CONTAINER (pParentDock));
 			if (pParentDock)
 			{
 				cairo_dock_redraw_icon (icon, CAIRO_CONTAINER (pParentDock));
@@ -632,12 +654,12 @@ static void _on_change_window_size_position (Icon *icon, XConfigureEvent *e)
 	icon->windowGeometry.height = h + top + bottom;
 	icon->windowGeometry.x = x - left;
 	icon->windowGeometry.y = y - top;
-	icon->iViewPortX = x / g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] + g_desktopGeometry.iCurrentViewportX;
-	icon->iViewPortY = y / g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] + g_desktopGeometry.iCurrentViewportY;
+	icon->iViewPortX = x / gldi_get_desktop_width() + g_desktopGeometry.iCurrentViewportX;
+	icon->iViewPortY = y / gldi_get_desktop_height() + g_desktopGeometry.iCurrentViewportY;
 	//g_print (" :: (%d;%d) %dx%d)\n", icon->windowGeometry.x, icon->windowGeometry.y, icon->windowGeometry.width, icon->windowGeometry.height);
 	
 	// on regarde si l'appli est sur le viewport courant.
-	if (x + w <= 0 || x >= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] || y + h <= 0 || y >= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL])  // not on this desktop (actually, it may be only a little bit on this desktop ... maybe we should use a % of the width, or a margin ...)
+	if (x + w <= 0 || x >= gldi_get_desktop_width() || y + h <= 0 || y >= gldi_get_desktop_height())  // not on this desktop (actually, it may be only a little bit on this desktop ... maybe we should use a % of the width, or a margin ...)
 	{
 		// applis du bureau courant seulement.
 		if (myTaskbarParam.bAppliOnCurrentDesktopOnly)
@@ -683,6 +705,16 @@ static gboolean _on_window_configured_notification (G_GNUC_UNUSED gpointer data,
 	if (e != NULL)  // a window
 	{
 		Icon *icon = g_hash_table_lookup (s_hXWindowTable, &Xid);
+
+		// if it's a window without icon and the active window, check if it's not above the dock
+		if (! CAIRO_DOCK_IS_APPLI (icon) && Xid == s_iCurrentActiveWindow)
+		{
+			Window iPropWindow;
+			XGetTransientForHint (s_XDisplay, Xid, &iPropWindow);
+			Icon *pParentIcon = g_hash_table_lookup (s_hXWindowTable, &iPropWindow);
+			cairo_dock_foreach_root_docks ((GFunc)_hide_show_if_on_our_way, pParentIcon);
+		}
+
 		if (! CAIRO_DOCK_IS_APPLI (icon) || cairo_dock_icon_is_being_removed (icon))
 			return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
 		_on_change_window_size_position (icon, e);
@@ -714,12 +746,15 @@ static void _on_change_window_icon (Icon *icon, CairoDock *pDock)
 {
 	if (cairo_dock_class_is_using_xicon (icon->cClass) || ! myTaskbarParam.bOverWriteXIcons)
 	{
-		cairo_dock_reload_icon_image (icon, CAIRO_CONTAINER (pDock));
-		if (pDock->iRefCount != 0)
-			cairo_dock_trigger_redraw_subdock_content (pDock);
-		cairo_dock_redraw_icon (icon, CAIRO_CONTAINER (pDock));
-		// notify everybody
-		cairo_dock_notify_on_object (&myTaskbarMgr, NOTIFICATION_APPLI_ICON_CHANGED, icon);
+		if (cairo_dock_get_icon_container (icon) != NULL)  // if the icon is not in a container (for instance inhibited), it's no use trying to load its image. It's not even useful to mark it as 'damaged', since anyway it will be loaded when inserted inside a container.
+		{
+			cairo_dock_load_icon_image (icon, CAIRO_CONTAINER (pDock));
+			if (pDock->iRefCount != 0)
+				cairo_dock_trigger_redraw_subdock_content (pDock);
+			cairo_dock_redraw_icon (icon, CAIRO_CONTAINER (pDock));
+			// notify everybody
+			cairo_dock_notify_on_object (&myTaskbarMgr, NOTIFICATION_APPLI_ICON_CHANGED, icon);
+		}
 	}
 }
 
@@ -731,11 +766,11 @@ static void _on_change_window_hints (Icon *icon, CairoDock *pDock, int iState)
 		if (pWMHints->flags & XUrgencyHint)
 		{
 			if (myTaskbarParam.bDemandsAttentionWithDialog || myTaskbarParam.cAnimationOnDemandsAttention)
-				cairo_dock_appli_demands_attention (icon);
+				cairo_dock_appli_demands_attention (icon, CAIRO_APPLI_URGENCY_HINT);
 		}
-		else if (icon->bIsDemandingAttention)
+		else if (icon->iDemandsAttention & CAIRO_APPLI_URGENCY_HINT)
 		{
-			cairo_dock_appli_stops_demanding_attention (icon);
+			cairo_dock_appli_stops_demanding_attention (icon, CAIRO_APPLI_URGENCY_HINT);
 		}
 		
 		if (iState == PropertyNewValue && (pWMHints->flags & (IconPixmapHint | IconMaskHint | IconWindowHint)))
@@ -743,7 +778,7 @@ static void _on_change_window_hints (Icon *icon, CairoDock *pDock, int iState)
 			//g_print ("%s change son icone\n", icon->cName);
 			if (pDock && (cairo_dock_class_is_using_xicon (icon->cClass) || ! myTaskbarParam.bOverWriteXIcons))
 			{
-				cairo_dock_reload_icon_image (icon, CAIRO_CONTAINER (pDock));
+				cairo_dock_load_icon_image (icon, CAIRO_CONTAINER (pDock));
 				if (pDock->iRefCount != 0)
 					cairo_dock_trigger_redraw_subdock_content (pDock);
 				cairo_dock_redraw_icon (icon, CAIRO_CONTAINER (pDock));
@@ -755,8 +790,8 @@ static void _on_change_window_hints (Icon *icon, CairoDock *pDock, int iState)
 	}
 	else  // no hints set on this window.
 	{
-		if (icon->bIsDemandingAttention)
-			cairo_dock_appli_stops_demanding_attention (icon);
+		if (icon->iDemandsAttention & CAIRO_APPLI_URGENCY_HINT)
+			cairo_dock_appli_stops_demanding_attention (icon, CAIRO_APPLI_URGENCY_HINT);
 	}
 }
 
@@ -800,7 +835,7 @@ static void _on_change_window_class (Icon *icon, G_GNUC_UNUSED CairoDock *pDock)
 	icon->pMimeTypes = g_strdupv ((gchar**)cairo_dock_get_class_mimetypes (icon->cClass));
 	g_free (icon->cCommand);
 	icon->cCommand = g_strdup (cairo_dock_get_class_command (icon->cClass));
-	cairo_dock_reload_icon_image (icon, CAIRO_CONTAINER (pParentDock));
+	cairo_dock_load_icon_image (icon, CAIRO_CONTAINER (pParentDock));
 	// notify everybody
 	cairo_dock_notify_on_object (&myTaskbarMgr, NOTIFICATION_APPLI_ICON_CHANGED, icon);
 }
@@ -938,7 +973,7 @@ void cairo_dock_start_applications_manager (CairoDock *pDock)
 	for (i = 0; i < iNbWindows; i ++)
 	{
 		Xid = pXWindowsList[i];
-		pIcon = cairo_dock_create_icon_from_xwindow (Xid, pDock);
+		pIcon = cairo_dock_create_icon_from_xwindow (Xid);
 		
 		if (pIcon != NULL)  // authorised window.
 		{
@@ -1020,7 +1055,6 @@ static void _cairo_dock_stop_application_manager (void)
 	cairo_dock_remove_all_applis_from_class_table ();  // enleve aussi les indicateurs.
 	
 	g_hash_table_foreach_remove (s_hXWindowTable, (GHRFunc) _cairo_dock_remove_one_appli, NULL);  // libere toutes les icones d'appli.
-	///cairo_dock_update_dock_size (g_pMainDock);
 	
 	cairo_dock_foreach_root_docks ((GFunc)_unhide_all_docks, NULL);
 }
@@ -1360,69 +1394,71 @@ static void _load_appli (Icon *icon)
 	}
 	
 	//\__________________ then draw the icon
-	int iWidth = icon->iImageWidth;
-	int iHeight = icon->iImageHeight;
-	cairo_surface_t *pPrevSurface = icon->pIconBuffer;
-	GLuint iPrevTexture = icon->iIconTexture;
-	icon->pIconBuffer = NULL;
-	icon->iIconTexture = 0;
+	int iWidth = cairo_dock_icon_get_allocated_width (icon);
+	int iHeight = cairo_dock_icon_get_allocated_height (icon);
+	cairo_surface_t *pPrevSurface = icon->image.pSurface;
+	GLuint iPrevTexture = icon->image.iTexture;
+	icon->image.pSurface = NULL;
+	icon->image.iTexture = 0;
 	
 	// use the thumbnail in the case of a minimized window.
 	if (myTaskbarParam.iMinimizedWindowRenderType == 1 && icon->bIsHidden && icon->iBackingPixmap != 0)
 	{
 		// create the thumbnail (window preview).
-		if (g_bUseOpenGL)
+		if (g_bUseOpenGL)  // in OpenGL, we should be able to use the texture-from-pixmap mechanism
 		{
-			///icon->iIconTexture = cairo_dock_texture_from_pixmap (icon->Xid, icon->iBackingPixmap);  // doesn't work any more since Compiz 0.9 :-(
+			GLuint iTexture = cairo_dock_texture_from_pixmap (icon->Xid, icon->iBackingPixmap);  // doesn't work any more since Compiz 0.9 :-(
+			if (iTexture)
+				cairo_dock_load_image_buffer_from_texture (&icon->image, iTexture, iWidth, iHeight);
 		}
-		if (icon->iIconTexture == 0)
+		if (icon->image.iTexture == 0)  // if not opengl or didn't work, get the content of the pixmap from the X server.
 		{
-			icon->pIconBuffer = cairo_dock_create_surface_from_xpixmap (icon->iBackingPixmap,
+			cairo_surface_t *pThumbnailSurface = cairo_dock_create_surface_from_xpixmap (icon->iBackingPixmap,
 				iWidth,
 				iHeight);
-			if (g_bUseOpenGL)
-				icon->iIconTexture = cairo_dock_create_texture_from_surface (icon->pIconBuffer);
+			cairo_dock_load_image_buffer_from_surface (&icon->image, pThumbnailSurface, iWidth, iHeight);
 		}
 		// draw the previous image as an emblem.
-		if (icon->iIconTexture != 0 && iPrevTexture != 0)
+		if (icon->image.iTexture != 0 && iPrevTexture != 0)
 		{
 			CairoDock *pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 			cairo_dock_print_overlay_on_icon_from_texture (icon, CAIRO_CONTAINER (pParentDock), iPrevTexture, CAIRO_OVERLAY_LOWER_LEFT);
-			/**CairoEmblem *e = cairo_dock_make_emblem_from_texture (iPrevTexture,icon);
-			cairo_dock_set_emblem_position (e, CAIRO_DOCK_EMBLEM_LOWER_LEFT);
-			cairo_dock_draw_emblem_on_icon (e, icon, CAIRO_CONTAINER (pParentDock));
-			g_free (e);  // on n'utilise pas cairo_dock_free_emblem pour ne pas detruire la texture avec.*/
 		}
-		else if (icon->pIconBuffer != NULL && pPrevSurface != NULL)
+		else if (icon->image.pSurface != NULL && pPrevSurface != NULL)
 		{
 			CairoDock *pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 			cairo_dock_print_overlay_on_icon_from_surface (icon, CAIRO_CONTAINER (pParentDock), pPrevSurface, 0, 0, CAIRO_OVERLAY_LOWER_LEFT);
-			/**CairoEmblem *e = cairo_dock_make_emblem_from_surface (pPrevSurface, 0, 0, icon);
-			cairo_dock_set_emblem_position (e, CAIRO_DOCK_EMBLEM_LOWER_LEFT);
-			cairo_dock_draw_emblem_on_icon (e, icon, CAIRO_CONTAINER (pParentDock));
-			g_free (e);  // meme remarque.*/
 		}
 	}
-	// or use the class icon
-	if (icon->iIconTexture == 0 && icon->pIconBuffer == NULL && myTaskbarParam.bOverWriteXIcons && ! cairo_dock_class_is_using_xicon (icon->cClass))
-		icon->pIconBuffer = cairo_dock_create_surface_from_class (icon->cClass, iWidth, iHeight);
-	// or use the X icon
-	if (icon->iIconTexture == 0 && icon->pIconBuffer == NULL)
-		icon->pIconBuffer = cairo_dock_create_surface_from_xwindow (icon->Xid, iWidth, iHeight);
-	// or use a default image
-	if (icon->iIconTexture == 0 && icon->pIconBuffer == NULL)  // certaines applis comme xterm ne definissent pas d'icone, on en met une par defaut.
+	
+	// in other cases (or if the preview couldn't be used)
+	if (icon->image.iTexture == 0 && icon->image.pSurface == NULL)
 	{
-		cd_debug ("%s (%ld) doesn't define any icon, we set the default one.", icon->cName, icon->Xid);
-		gchar *cIconPath = cairo_dock_search_image_s_path (CAIRO_DOCK_DEFAULT_APPLI_ICON_NAME);
-		if (cIconPath == NULL)  // image non trouvee.
+		cairo_surface_t *pSurface = NULL;
+		// or use the class icon
+		if (myTaskbarParam.bOverWriteXIcons && ! cairo_dock_class_is_using_xicon (icon->cClass))
+			pSurface = cairo_dock_create_surface_from_class (icon->cClass, iWidth, iHeight);
+		// or use the X icon
+		if (pSurface == NULL)
+			pSurface = cairo_dock_create_surface_from_xwindow (icon->Xid, iWidth, iHeight);
+		// or use a default image
+		if (pSurface == NULL)  // some applis like xterm don't define any icon, set the default one.
 		{
-			cIconPath = g_strdup (GLDI_SHARE_DATA_DIR"/icons/"CAIRO_DOCK_DEFAULT_APPLI_ICON_NAME);
+			cd_debug ("%s (%ld) doesn't define any icon, we set the default one.", icon->cName, icon->Xid);
+			gchar *cIconPath = cairo_dock_search_image_s_path (CAIRO_DOCK_DEFAULT_APPLI_ICON_NAME);
+			if (cIconPath == NULL)  // image non trouvee.
+			{
+				cIconPath = g_strdup (GLDI_SHARE_DATA_DIR"/icons/"CAIRO_DOCK_DEFAULT_APPLI_ICON_NAME);
+			}
+			pSurface = cairo_dock_create_surface_from_image_simple (cIconPath,
+				iWidth,
+				iHeight);
+			g_free (cIconPath);
 		}
-		icon->pIconBuffer = cairo_dock_create_surface_from_image_simple (cIconPath,
-			iWidth,
-			iHeight);
-		g_free (cIconPath);
+		if (pSurface != NULL)
+			cairo_dock_load_image_buffer_from_surface (&icon->image, pSurface, iWidth, iHeight);
 	}
+	
 	// bent the icon in the case of a minimized window and if defined in the config.
 	if (icon->bIsHidden && myTaskbarParam.iMinimizedWindowRenderType == 2)
 	{
@@ -1443,7 +1479,7 @@ static gboolean _delete_appli (Icon *pIcon)
 	return FALSE;
 }
 
-static Icon * cairo_dock_create_icon_from_xwindow (Window Xid, G_GNUC_UNUSED CairoDock *pDock)
+static Icon * cairo_dock_create_icon_from_xwindow (Window Xid)
 {
 	//\__________________ On cree l'icone.
 	Window XParentWindow = 0;
@@ -1455,7 +1491,7 @@ static Icon * cairo_dock_create_icon_from_xwindow (Window Xid, G_GNUC_UNUSED Cai
 		if (pParentIcon != NULL)
 		{
 			cd_debug ("%s requiert votre attention indirectement !", pParentIcon->cName);
-			cairo_dock_appli_demands_attention (pParentIcon);
+			cairo_dock_appli_demands_attention (pParentIcon, CAIRO_APPLI_DEMANDS_ATTENTION);
 		}
 		else
 			cd_debug ("ce dialogue est bien bruyant ! (%d)", XParentWindow);
@@ -1480,15 +1516,12 @@ static Icon * cairo_dock_create_icon_from_xwindow (Window Xid, G_GNUC_UNUSED Cai
 		{
 			//Display *display = gdk_x11_get_default_xdisplay ();
 			icon->iBackingPixmap = XCompositeNameWindowPixmap (s_XDisplay, Xid);
+			if (icon->iBackingPixmap != 0)
+				XCompositeRedirectWindow (s_XDisplay, Xid, 0);  // redirect the window content to the backing pixmap (the WM may or may not already do this).
 			/*icon->iDamageHandle = XDamageCreate (s_XDisplay, Xid, XDamageReportNonEmpty);  // XDamageReportRawRectangles
 			cd_debug ("backing pixmap : %d ; iDamageHandle : %d", icon->iBackingPixmap, icon->iDamageHandle);*/
 		}
 		#endif
-		
-		/**if (pDock)
-		{
-			cairo_dock_trigger_load_icon_buffers (icon);
-		}*/
 	}
 	
 	//\____________ On enregistre l'appli et on commence a la surveiller.
