@@ -64,7 +64,6 @@
 #include "cairo-dock-data-renderer.h"  // cairo_dock_refresh_data_renderer
 #include "cairo-dock-callbacks.h"
 
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern CairoDockHidingEffect *g_pHidingBackend;
 extern CairoDockHidingEffect *g_pKeepingBelowBackend;
 extern CairoDockGLConfig g_openglConfig;
@@ -405,7 +404,8 @@ void cairo_dock_on_change_icon (Icon *pLastPointedIcon, Icon *pPointedIcon, Cair
 		
 		if (bStartAnimation)
 		{
-			pPointedIcon->iAnimationState = CAIRO_DOCK_STATE_MOUSE_HOVERED;
+			///pPointedIcon->iAnimationState = CAIRO_DOCK_STATE_MOUSE_HOVERED;
+			cairo_dock_mark_icon_as_hovered_by_mouse (pPointedIcon);  // mark the animation as 'hover' if it's not already in another state (clicked, etc).
 			cairo_dock_launch_animation (CAIRO_CONTAINER (pDock));
 		}
 	}
@@ -454,14 +454,13 @@ static void _cairo_dock_make_icon_glide (Icon *pPointedIcon, Icon *pMovingicon,
 		}
 		else
 		{
-			double fMaxScale = (icon->fHeight != 0 ? (pDock->container.bIsHorizontal ? icon->iImageHeight : icon->iImageWidth) / icon->fHeight : 1.);
 			//g_print ("deplacement de %s vers la gauche (%.2f / %d)\n", icon->cName, icon->fDrawX + icon->fWidth * fMaxScale + myIconsParam.iIconGap, pDock->container.iMouseX);
-			if (icon->fXAtRest < pMovingicon->fXAtRest && icon->fDrawX + icon->fWidth * fMaxScale + myIconsParam.iIconGap >= pDock->container.iMouseX && icon->fGlideOffset == 0)  // icone entre l'icone deplacee et le curseur.
+			if (icon->fXAtRest < pMovingicon->fXAtRest && icon->fDrawX + icon->image.iWidth + myIconsParam.iIconGap >= pDock->container.iMouseX && icon->fGlideOffset == 0)  // icone entre l'icone deplacee et le curseur.
 			{
 				//g_print ("  %s glisse vers la droite\n", icon->cName);
 				icon->iGlideDirection = 1;
 			}
-			else if (icon->fXAtRest < pMovingicon->fXAtRest && icon->fDrawX + icon->fWidth * fMaxScale + myIconsParam.iIconGap <= pDock->container.iMouseX && icon->fGlideOffset != 0)
+			else if (icon->fXAtRest < pMovingicon->fXAtRest && icon->fDrawX + icon->image.iWidth + myIconsParam.iIconGap <= pDock->container.iMouseX && icon->fGlideOffset != 0)
 			{
 				//g_print ("  %s glisse vers la gauche\n", icon->cName);
 				icon->iGlideDirection = -1;
@@ -545,7 +544,8 @@ gboolean cairo_dock_on_motion_notify (GtkWidget* pWidget,
 		if (s_pIconClicked != NULL && s_pIconClicked->iAnimationState != CAIRO_DOCK_STATE_REMOVE_INSERT && ! myDocksParam.bLockIcons && ! myDocksParam.bLockAll && (fabs (pMotion->x - s_iClickX) > CD_CLICK_ZONE || fabs (pMotion->y - s_iClickY) > CD_CLICK_ZONE) && ! pDock->bPreventDraggingIcons)
 		{
 			s_bIconDragged = TRUE;
-			s_pIconClicked->iAnimationState = CAIRO_DOCK_STATE_FOLLOW_MOUSE;
+			///s_pIconClicked->iAnimationState = CAIRO_DOCK_STATE_FOLLOW_MOUSE;
+			cairo_dock_mark_icon_as_following_mouse (s_pIconClicked);
 			//pDock->fAvoidingMouseMargin = .5;
 			pDock->iAvoidingMouseIconType = s_pIconClicked->iGroup;  // on pourrait le faire lors du clic aussi.
 			s_pIconClicked->fScale = cairo_dock_get_icon_max_scale (s_pIconClicked);
@@ -642,6 +642,7 @@ gboolean cairo_dock_on_leave_dock_notification2 (G_GNUC_UNUSED gpointer data, Ca
 }
 gboolean cairo_dock_on_leave_dock_notification (G_GNUC_UNUSED gpointer data, CairoDock *pDock, G_GNUC_UNUSED gboolean *bStartAnimation)
 {
+	//g_print ("%s (%d, %d)\n", __func__, pDock->iRefCount, pDock->bHasModalWindow);
 	//\_______________ Arrive ici, on est sorti du dock.
 	pDock->container.bInside = FALSE;
 	pDock->iAvoidingMouseIconType = -1;
@@ -658,8 +659,7 @@ gboolean cairo_dock_on_leave_dock_notification (G_GNUC_UNUSED gpointer data, Cai
 		s_pDockShowingSubDock = NULL;
 		s_pSubDockShowing = NULL;
 	}
-	
-	//g_print ("%s (%d, %d)\n", __func__, pDock->iRefCount, pDock->bMenuVisible);
+	//g_print ("%s (%d, %d)\n", __func__, pDock->iRefCount, pDock->bHasModalWindow);
 	
 	//\_______________ If a modal window is raised, we discard the 'leave-event' to stay in the up position.
 	if (pDock->bHasModalWindow)
@@ -1028,6 +1028,7 @@ static gboolean _double_click_delay_over (Icon *icon)
 	CairoDock *pDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 	if (pDock)
 	{
+		cairo_dock_stop_icon_attention (icon, pDock);  // we consider that clicking on the icon is an acknowledge of the demand of attention.
 		pDock->container.iMouseX = s_iFirstClickX;
 		pDock->container.iMouseY = s_iFirstClickY;
 		cairo_dock_notify_on_object (pDock, NOTIFICATION_CLICK_ICON, icon, pDock, GDK_BUTTON1_MASK);
@@ -1036,7 +1037,6 @@ static gboolean _double_click_delay_over (Icon *icon)
 		
 		cairo_dock_start_icon_animation (icon, pDock);
 	}
-	icon->bIsDemandingAttention = FALSE;  // on considere que si l'utilisateur clique sur l'icone, c'est qu'il a pris acte de la notification.
 	icon->iSidDoubleClickDelay = 0;
 	return FALSE;
 }
@@ -1111,12 +1111,13 @@ gboolean cairo_dock_on_button_press (G_GNUC_UNUSED GtkWidget* pWidget, GdkEventB
 							}
 							else
 							{
+								cairo_dock_stop_icon_attention (icon, pDock);  // we consider that clicking on the icon is an acknowledge of the demand of attention.
+								
 								cairo_dock_notify_on_object (pDock, NOTIFICATION_CLICK_ICON, icon, pDock, pButton->state);
 								if (pDock->bIsMainDock && pDock->iVisibility == CAIRO_DOCK_VISI_SHORTKEY)
 									s_bHideAfterShortcut = TRUE;
 								
 								cairo_dock_start_icon_animation (icon, pDock);
-								icon->bIsDemandingAttention = FALSE;  // on considere que si l'utilisateur clique sur l'icone, c'est qu'il a pris acte de la notification.
 							}
 						}
 					}
@@ -1358,16 +1359,22 @@ gboolean cairo_dock_on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent,
 		
 		cairo_dock_replace_all_dialogs ();
 		
-		if (bIsNowSized && g_bUseOpenGL)  // in OpenGL, 
+		if (bIsNowSized && g_bUseOpenGL)  // in OpenGL, the context is linked to the window; now that the window has a correct size, the context is ready -> draw things that couldn't be drawn until now.
 		{
 			Icon *icon;
 			GList *ic;
 			for (ic = pDock->icons; ic != NULL; ic = ic->next)
 			{
 				icon = ic->data;
-				if (icon->bDamaged)
+				gboolean bDamaged = icon->bDamaged;  // if bNeedApplyBackground is also TRUE, applying the background will remove the 'damage' flag.
+				if (icon->bNeedApplyBackground)  // if both are TRUE, we need to do both (for instance, the data-renderer might not redraw the icon (progressbar)). draw the bg first so that we don't draw it twice.
 				{
-					cd_debug ("This icon %s is damaged", icon->cName);
+					icon->bNeedApplyBackground = FALSE;  // set to FALSE, if it doesn't work here, it will probably never do.
+					cairo_dock_apply_icon_background_opengl (icon);
+				}
+				if (bDamaged)
+				{
+					//g_print ("This icon %s is damaged\n", icon->cName);
 					icon->bDamaged = FALSE;
 					if (cairo_dock_get_icon_data_renderer (icon) != NULL)
 					{
@@ -1385,6 +1392,8 @@ gboolean cairo_dock_on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent,
 					{
 						cairo_dock_load_icon_image (icon, CAIRO_CONTAINER (pDock));
 					}
+					if (pDock->iRefCount != 0)  // now that the icon image is correct, redraw the pointing icon if needed
+						cairo_dock_trigger_redraw_subdock_content (pDock);
 				}
 			}
 		}
@@ -1714,10 +1723,12 @@ static void _cairo_dock_show_dock_at_mouse (CairoDock *pDock)
 	g_return_if_fail (pDock != NULL);
 	gldi_container_update_mouse_position (CAIRO_CONTAINER (pDock));
 	
+	int W = gldi_dock_get_screen_width (pDock), H = gldi_dock_get_screen_height (pDock);
+	int iScreenOffsetX = gldi_dock_get_screen_offset_x (pDock), iScreenOffsetY = gldi_dock_get_screen_offset_y (pDock);
 	///pDock->iGapX = pDock->container.iWindowPositionX + iMouseX - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] * pDock->fAlign;
 	///pDock->iGapY = (pDock->container.bDirectionUp ? g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - (pDock->container.iWindowPositionY + iMouseY) : pDock->container.iWindowPositionY + iMouseY);
-	pDock->iGapX = pDock->container.iWindowPositionX + pDock->container.iMouseX - (g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - pDock->container.iWidth) * pDock->fAlign - pDock->container.iWidth/2 - pDock->iScreenOffsetX;
-	pDock->iGapY = (pDock->container.bDirectionUp ? g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - (pDock->container.iWindowPositionY + pDock->container.iMouseY) : pDock->container.iWindowPositionY + pDock->container.iMouseY) - pDock->iScreenOffsetY;
+	pDock->iGapX = pDock->container.iWindowPositionX + pDock->container.iMouseX - (W - pDock->container.iWidth) * pDock->fAlign - pDock->container.iWidth/2 - iScreenOffsetX;
+	pDock->iGapY = (pDock->container.bDirectionUp ? H - (pDock->container.iWindowPositionY + pDock->container.iMouseY) : pDock->container.iWindowPositionY + pDock->container.iMouseY) - iScreenOffsetY;
 	cd_debug (" => %d;%d", g_pMainDock->iGapX, g_pMainDock->iGapY);
 	
 	int iNewPositionX, iNewPositionY;
@@ -1727,13 +1738,13 @@ static void _cairo_dock_show_dock_at_mouse (CairoDock *pDock)
 	cd_debug (" ==> %d;%d", iNewPositionX, iNewPositionY);
 	if (iNewPositionX < 0)
 		iNewPositionX = 0;
-	else if (iNewPositionX + pDock->container.iWidth > g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal])
-		iNewPositionX = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - pDock->container.iWidth;
+	else if (iNewPositionX + pDock->container.iWidth > W)
+		iNewPositionX = W - pDock->container.iWidth;
 	
 	if (iNewPositionY < 0)
 		iNewPositionY = 0;
-	else if (iNewPositionY + pDock->container.iHeight > g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal])
-		iNewPositionY = g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - pDock->container.iHeight;
+	else if (iNewPositionY + pDock->container.iHeight > H)
+		iNewPositionY = H - pDock->container.iHeight;
 	
 	gtk_window_move (GTK_WINDOW (pDock->container.pWidget),
 		(pDock->container.bIsHorizontal ? iNewPositionX : iNewPositionY),
