@@ -297,25 +297,21 @@ void cairo_dock_render_overlays_to_context (CairoDataRenderer *pRenderer, int iN
 static void _cairo_dock_render_to_context (CairoDataRenderer *pRenderer, Icon *pIcon, CairoContainer *pContainer, cairo_t *pCairoContext)
 {
 	cairo_t *ctx = NULL;
-	if (pRenderer->bUseOverlay && pRenderer->pOverlay != NULL && pRenderer->pOverlay->image.pSurface != NULL)
+	if (pRenderer->bUseOverlay && pRenderer->pOverlay != NULL)
 	{
-		ctx = cairo_create (pRenderer->pOverlay->image.pSurface);
-		cairo_dock_erase_cairo_context (ctx);
+		CairoDataToRenderer *pData = cairo_data_renderer_get_data (pRenderer);
+		if (! pData->bHasValue)  // if no value has been set yet, it's better to not draw anything, since the icon already has an image (we draw on an overlay).
+			return;
+		ctx = cairo_dock_begin_draw_image_buffer_cairo (&pRenderer->pOverlay->image, 0, NULL);
 		pCairoContext = ctx;
 	}
-	else if (pCairoContext == NULL && pIcon->pIconBuffer)
+	else
 	{
-		ctx = cairo_create (pIcon->pIconBuffer);
+		ctx = cairo_dock_begin_draw_icon_cairo (pIcon, 0, pCairoContext);
 		pCairoContext = ctx;
 	}
 	g_return_if_fail (pCairoContext != NULL);
 	
-	//\________________ On efface tout.
-	cairo_set_source_rgba (pCairoContext, 0.0, 0.0, 0.0, 0.0);
-	cairo_set_operator (pCairoContext, CAIRO_OPERATOR_SOURCE);
-	cairo_paint (pCairoContext);
-	cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
-	
 	//\________________ On dessine.
 	cairo_save (pCairoContext);
 	if ((pRenderer->iRotateTheme == CD_RENDERER_ROTATE_WITH_CONTAINER && pContainer->bIsHorizontal == CAIRO_DOCK_VERTICAL) || pRenderer->iRotateTheme == CD_RENDERER_ROTATE_YES)
@@ -339,20 +335,19 @@ static void _cairo_dock_render_to_context (CairoDataRenderer *pRenderer, Icon *p
 	}*/
 	cairo_restore (pCairoContext);
 	
-	/**if (pContainer->bUseReflect)
-	{
-		cairo_dock_add_reflection_to_icon (pIcon, pContainer);
-	}*/
-	
-	if (CAIRO_DOCK_CONTAINER_IS_OPENGL (pContainer))
+	if (pRenderer->bUseOverlay && pRenderer->pOverlay != NULL)
+		cairo_dock_end_draw_image_buffer_cairo (&pRenderer->pOverlay->image);
+	else
+		cairo_dock_end_draw_image_buffer_cairo (&pIcon->image);
+	/**if (CAIRO_DOCK_CONTAINER_IS_OPENGL (pContainer))
 	{
 		if (pRenderer->bUseOverlay)
 			pRenderer->pOverlay->image.iTexture = cairo_dock_create_texture_from_surface (pRenderer->pOverlay->image.pSurface);
 		else
 			cairo_dock_update_icon_texture (pIcon);
-	}
+	}*/
 	
-	if (ctx != NULL)
+	if (ctx != pCairoContext)
 		cairo_destroy (ctx);
 }
 
@@ -363,7 +358,7 @@ static void _cairo_dock_render_to_texture (CairoDataRenderer *pRenderer, Icon *p
 		CairoDataToRenderer *pData = cairo_data_renderer_get_data (pRenderer);
 		if (! pData->bHasValue)  // if no value has been set yet, it's better to not draw anything, since the icon already has an image (we draw on an overlay).
 			return;
-		if (! cairo_dock_begin_draw_image_buffer (&pRenderer->pOverlay->image, pContainer, 0))
+		if (! cairo_dock_begin_draw_image_buffer_opengl (&pRenderer->pOverlay->image, pContainer, 0))
 		{
 			pIcon->bDamaged = TRUE;  // damage the icon so that it (and therefore its dada-renderer) will be redrawn.
 			return ;
@@ -398,7 +393,7 @@ static void _cairo_dock_render_to_texture (CairoDataRenderer *pRenderer, Icon *p
 	
 	if (pRenderer->bUseOverlay)
 	{
-		cairo_dock_end_draw_image_buffer (&pRenderer->pOverlay->image, pContainer);
+		cairo_dock_end_draw_image_buffer_opengl (&pRenderer->pOverlay->image, pContainer);
 	}
 	else
 	{
@@ -599,7 +594,9 @@ void cairo_dock_add_new_data_renderer_on_icon (Icon *pIcon, CairoContainer *pCon
 	//\___________________ load it.
 	_cairo_dock_init_data_renderer (pRenderer, pAttribute);
 	
-	cairo_dock_get_icon_extent (pIcon, &pRenderer->iWidth, &pRenderer->iHeight);
+	pRenderer->iWidth = cairo_dock_icon_get_allocated_width (pIcon);  // we don't need the icon to be loaded already, its allocated size is enough
+	pRenderer->iHeight = cairo_dock_icon_get_allocated_height (pIcon);
+	///cairo_dock_get_icon_extent (pIcon, &pRenderer->iWidth, &pRenderer->iHeight);
 	
 	gboolean bLoadTextures = FALSE;
 	if (CAIRO_DOCK_CONTAINER_IS_OPENGL (pContainer) && pRenderer->interface.render_opengl)
