@@ -45,7 +45,7 @@
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-keyfile-utilities.h"
-#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
+#include "cairo-dock-themes-manager.h"  // cairo_dock_add_conf_file
 #include "cairo-dock-dock-factory.h"
 #include "cairo-dock-dock-facility.h"
 #include "cairo-dock-draw.h"
@@ -66,9 +66,9 @@ CairoDock *g_pMainDock = NULL;  // pointeur sur le dock principal.
 CairoDockHidingEffect *g_pHidingBackend = NULL;
 CairoDockHidingEffect *g_pKeepingBelowBackend = NULL;
 
+// dependancies
 extern gchar *g_cConfFile;
 extern gchar *g_cCurrentThemePath;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern gboolean g_bUseOpenGL;
 
 // private
@@ -84,6 +84,8 @@ static CairoKeyBinding *s_pPopupBinding = NULL;  // option 'pop up on shortkey'
 
 static gboolean cairo_dock_read_root_dock_config (const gchar *cDockName, CairoDock *pDock);
 
+static void cairo_dock_synchronize_sub_docks_orientation (CairoDock *pDock, gboolean bUpdateDockSize);
+
 typedef struct {
 	gboolean bUpToDate;
 	gint x;
@@ -231,12 +233,6 @@ void cairo_dock_main_dock_to_sub_dock (CairoDock *pDock, CairoDock *pParentDock,
 		cairo_dock_make_sub_dock (pDock, pParentDock, cRendererName);
 		cairo_dock_update_dock_size (pDock);
 		
-		/**if (iScreenBorder != (((! pDock->container.bIsHorizontal) << 1) | (! pDock->container.bDirectionUp)))
-		{
-			cd_debug ("changement de position -> %d/%d", pDock->container.bIsHorizontal, pDock->container.bDirectionUp);
-			cairo_dock_reload_reflects_in_dock (pDock);
-		}*/
-		
 		//\__________________ remove from main-dock land
 		const gchar *cDockName = cairo_dock_search_dock_name (pDock);
 		cairo_dock_remove_root_dock_config (cDockName);  // just in case.
@@ -481,10 +477,12 @@ static void _cairo_dock_foreach_icons_in_dock (G_GNUC_UNUSED gchar *cDockName, C
 {
 	CairoDockForeachIconFunc pFunction = data[0];
 	gpointer pUserData = data[1];
-	GList *ic;
-	for (ic = pDock->icons; ic != NULL; ic = ic->next)
+	GList *ic = pDock->icons, *next_ic;
+	while (ic != NULL)
 	{
+		next_ic = ic->next;  // the function bolew may remove the current icon
 		pFunction ((Icon*)ic->data, CAIRO_CONTAINER (pDock), pUserData);
+		ic = next_ic;
 	}
 }
 void cairo_dock_foreach_icons_in_docks (CairoDockForeachIconFunc pFunction, gpointer pUserData)
@@ -645,7 +643,7 @@ void cairo_dock_write_root_dock_gaps (CairoDock *pDock)
 		gchar *cConfFilePath = g_strdup_printf ("%s/%s.conf", g_cCurrentThemePath, cDockName);
 		if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
 		{
-			cairo_dock_copy_file (GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
+			cairo_dock_add_conf_file (GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
 		}
 		
 		cairo_dock_update_conf_file (cConfFilePath,
@@ -764,19 +762,12 @@ static gboolean cairo_dock_read_root_dock_config (const gchar *cDockName, CairoD
 	pDock->iGapX = cairo_dock_get_integer_key_value (pKeyFile, "Behavior", "x gap", &bFlushConfFileNeeded, 0, "Position", NULL);
 	pDock->iGapY = cairo_dock_get_integer_key_value (pKeyFile, "Behavior", "y gap", &bFlushConfFileNeeded, 0, "Position", NULL);
 	
-	CairoDockPositionType iScreenBorder = cairo_dock_get_integer_key_value (pKeyFile, "Behavior", "screen border", &bFlushConfFileNeeded, 0, "Position", NULL);
-	cairo_dock_set_dock_orientation (pDock, iScreenBorder);
-	
 	pDock->fAlign = cairo_dock_get_double_key_value (pKeyFile, "Behavior", "alignment", &bFlushConfFileNeeded, 0.5, "Position", NULL);
 	
-	if (myDocksParam.bUseXinerama)
-	{
-		int iNumScreen = cairo_dock_get_integer_key_value (pKeyFile, "Behavior", "num screen", &bFlushConfFileNeeded, 0, "Position", NULL);
-		pDock->iNumScreen = iNumScreen;
-		cairo_dock_get_screen_offsets (iNumScreen, &pDock->iScreenOffsetX, &pDock->iScreenOffsetY);
-	}
-	else
-		pDock->iNumScreen = pDock->iScreenOffsetX = pDock->iScreenOffsetY = 0;
+	pDock->iNumScreen = cairo_dock_get_integer_key_value (pKeyFile, "Behavior", "num_screen", &bFlushConfFileNeeded, GLDI_DEFAULT_SCREEN, "Position", NULL);
+	
+	CairoDockPositionType iScreenBorder = cairo_dock_get_integer_key_value (pKeyFile, "Behavior", "screen border", &bFlushConfFileNeeded, 0, "Position", NULL);
+	cairo_dock_set_dock_orientation (pDock, iScreenBorder);  // do it after all position parameters have been set; it sets the sub-dock orientation too.
 	
 	//\______________ Visibility.
 	CairoDockVisibility iVisibility = cairo_dock_get_integer_key_value (pKeyFile, "Behavior", "visibility", &bFlushConfFileNeeded, FALSE, "Position", NULL);
@@ -845,7 +836,7 @@ void cairo_dock_remove_root_dock_config (const gchar *cDockName)
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s.conf", g_cCurrentThemePath, cDockName);
 	if (g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
 	{
-		g_remove (cConfFilePath);
+		cairo_dock_delete_conf_file (cConfFilePath);
 	}
 	g_free (cConfFilePath);
 }
@@ -855,7 +846,7 @@ void cairo_dock_add_root_dock_config_for_name (const gchar *cDockName)
 	// on cree le fichier de conf a partir du template.
 	cd_debug ("%s (%s)", __func__, cDockName);
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s.conf", g_cCurrentThemePath, cDockName);
-	cairo_dock_copy_file (GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
+	cairo_dock_add_conf_file (GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
 	
 	// on placera le nouveau dock a l'oppose du main dock, meme ecran et meme visibilite.
 	cairo_dock_update_conf_file (cConfFilePath,
@@ -865,7 +856,7 @@ void cairo_dock_add_root_dock_config_for_name (const gchar *cDockName)
 			(g_pMainDock->container.bDirectionUp ? 3 : 2)),
 		G_TYPE_INT, "Behavior", "visibility",
 		g_pMainDock->iVisibility,
-		G_TYPE_INT, "Behavior", "num screen",
+		G_TYPE_INT, "Behavior", "num_screen",
 		g_pMainDock->iNumScreen,
 		G_TYPE_INVALID);
 	g_free (cConfFilePath);
@@ -914,18 +905,12 @@ static void _cairo_dock_reposition_one_root_dock (const gchar *cDockName, CairoD
 	{
 		if (!pDock->bIsMainDock)
 			cairo_dock_read_root_dock_config (cDockName, pDock);  // relit toute la conf.
-		else
-		{
-			if (myDocksParam.bUseXinerama)
-				cairo_dock_get_screen_offsets (pDock->iNumScreen, &pDock->iScreenOffsetX, &pDock->iScreenOffsetY);
-			else
-				pDock->iNumScreen = pDock->iScreenOffsetX = pDock->iScreenOffsetY = 0;
-		}
+		
 		cairo_dock_update_dock_size (pDock);  // la taille max du dock depend de la taille de l'ecran, donc on recalcule son ratio.
 		cairo_dock_move_resize_dock (pDock);
 		gtk_widget_show (pDock->container.pWidget);
 		gtk_widget_queue_draw (pDock->container.pWidget);
-		cairo_dock_synchronize_sub_docks_orientation (pDock, FALSE);
+		cairo_dock_synchronize_sub_docks_orientation (pDock, TRUE);
 	}
 }
 void cairo_dock_reposition_root_docks (gboolean bExceptMainDock)
@@ -933,23 +918,25 @@ void cairo_dock_reposition_root_docks (gboolean bExceptMainDock)
 	g_hash_table_foreach (s_hDocksTable, (GHFunc)_cairo_dock_reposition_one_root_dock, GINT_TO_POINTER (bExceptMainDock));
 }
 
-void cairo_dock_synchronize_one_sub_dock_orientation (CairoDock *pSubDock, CairoDock *pDock, gboolean bReloadBuffersIfNecessary)
+void cairo_dock_synchronize_one_sub_dock_orientation (CairoDock *pSubDock, CairoDock *pDock, gboolean bUpdateDockSize)
 {
 	if (pSubDock->container.bDirectionUp != pDock->container.bDirectionUp || pSubDock->container.bIsHorizontal != pDock->container.bIsHorizontal)
 	{
 		pSubDock->container.bDirectionUp = pDock->container.bDirectionUp;
 		pSubDock->container.bIsHorizontal = pDock->container.bIsHorizontal;
-		/**if (bReloadBuffersIfNecessary)
-			cairo_dock_reload_reflects_in_dock (pSubDock);*/
-		cairo_dock_update_dock_size (pSubDock);
 		
-		cairo_dock_synchronize_sub_docks_orientation (pSubDock, bReloadBuffersIfNecessary);
+		cairo_dock_update_dock_size (pSubDock);
 	}
-	pSubDock->iScreenOffsetX = pDock->iScreenOffsetX;
-	pSubDock->iScreenOffsetY = pDock->iScreenOffsetY;
+	else if (bUpdateDockSize)
+	{
+		cairo_dock_update_dock_size (pSubDock);
+	}
+	pSubDock->iNumScreen = pDock->iNumScreen;
+	
+	cairo_dock_synchronize_sub_docks_orientation (pSubDock, bUpdateDockSize);
 }
 
-void cairo_dock_synchronize_sub_docks_orientation (CairoDock *pDock, gboolean bReloadBuffersIfNecessary)
+static void cairo_dock_synchronize_sub_docks_orientation (CairoDock *pDock, gboolean bUpdateDockSize)
 {
 	GList* ic;
 	Icon *icon;
@@ -957,7 +944,7 @@ void cairo_dock_synchronize_sub_docks_orientation (CairoDock *pDock, gboolean bR
 	{
 		icon = ic->data;
 		if (icon->pSubDock != NULL)
-			cairo_dock_synchronize_one_sub_dock_orientation (icon->pSubDock, pDock, bReloadBuffersIfNecessary);
+			cairo_dock_synchronize_one_sub_dock_orientation (icon->pSubDock, pDock, bUpdateDockSize);
 	}
 }
 
@@ -985,7 +972,7 @@ void cairo_dock_set_dock_orientation (CairoDock *pDock, CairoDockPositionType iS
 		case CAIRO_DOCK_NB_POSITIONS :
 		break;
 	}
-	cairo_dock_synchronize_sub_docks_orientation (pDock, FALSE);  // synchronize l'orientation et l'offset Xinerama des sous-docks ainsi que les reflets cairo.
+	cairo_dock_synchronize_sub_docks_orientation (pDock, FALSE);  // synchronize l'orientation et l'offset Xinerama des sous-docks.
 }
 
 
@@ -1113,6 +1100,11 @@ static void _cairo_dock_unhide_root_dock_on_mouse_hit (CairoDock *pDock, CDMouse
 	if (! pDock->bAutoHide && pDock->iVisibility != CAIRO_DOCK_VISI_KEEP_BELOW)
 		return;
 	
+	int iScreenWidth = gldi_dock_get_screen_width (pDock);
+	int iScreenHeight = gldi_dock_get_screen_height (pDock);
+	int iScreenX = gldi_dock_get_screen_offset_x (pDock);
+	int iScreenY = gldi_dock_get_screen_offset_y (pDock);
+	
 	//\________________ On recupere la position du pointeur.
 	gint x, y;
 	if (! pMouse->bUpToDate)  // pas encore recupere le pointeur.
@@ -1146,33 +1138,37 @@ static void _cairo_dock_unhide_root_dock_on_mouse_hit (CairoDock *pDock, CDMouse
 		x = pMouse->y;
 		y = pMouse->x;
 	}
+	y -= iScreenY;  // relative to the border of the dock's screen.
 	if (pDock->container.bDirectionUp)
 	{
-		y = g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - 1 - y;
+		y = iScreenHeight - 1 - y;
+		
 	}
 	
 	//\________________ On verifie les conditions.
-	int x1, x2;  // coordinates range on the screen edge.
+	int x1, x2;  // coordinates range on the X screen edge.
 	gboolean bShow = FALSE;
+	int Ws = (pDock->container.bIsHorizontal ? gldi_get_desktop_width() : gldi_get_desktop_height());
 	switch (myDocksParam.iCallbackMethod)
 	{
 		case CAIRO_HIT_SCREEN_BORDER:
 		default:
 			if (y != 0)
 				break;
+			if (x < iScreenX || x > iScreenX + iScreenWidth - 1)  // only check the border of the dock's screen.
+				break ;
 			bShow = TRUE;
 		break;
-		
 		case CAIRO_HIT_DOCK_PLACE:
+			
 			if (y != 0)
 				break;
-
 			x1 = pDock->container.iWindowPositionX + (pDock->container.iWidth - pDock->iActiveWidth) * pDock->fAlign;
 			x2 = x1 + pDock->iActiveWidth;
-			if (x1 < 15)  // avoid corners, since this is actually the purpose of this option (corners can be used by the WM to trigger actions).
-				x1 = 15;
-			if (x2 > g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - 15)
-				x2 = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - 15;
+			if (x1 < 8)  // avoid corners, since this is actually the purpose of this option (corners can be used by the WM to trigger actions).
+				x1 = 8;
+			if (x2 > Ws - 8)
+				x2 = Ws - 8;
 			if (x < x1 || x > x2)
 				break;
 			bShow = TRUE;
@@ -1180,7 +1176,7 @@ static void _cairo_dock_unhide_root_dock_on_mouse_hit (CairoDock *pDock, CDMouse
 		case CAIRO_HIT_SCREEN_CORNER:
 			if (y != 0)
 				break;
-			if (x > 0 && x < g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - 1)
+			if (x > 0 && x < Ws - 1)  // avoid the corners of the X screen (since we can't actually hit the corner of a screen that would be inside the X screen).
 				break ;
 			bShow = TRUE;
 		break;
@@ -1316,7 +1312,7 @@ void cairo_dock_set_dock_visibility (CairoDock *pDock, CairoDockVisibility iVisi
 				pDock->bAutoHide = FALSE;
 				cairo_dock_start_showing (pDock);
 			}
-			if (bAutoHideOnOverlap || myDocksParam.bAutoHideOnFullScreen)
+			if (bAutoHideOnOverlap)
 			{
 				pDock->bTemporaryHidden = pDock->bAutoHide;  // astuce pour utiliser la fonction ci-dessous.
 				cairo_dock_hide_show_if_current_window_is_on_our_way (pDock);
@@ -1441,14 +1437,15 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 
 	pPosition->fAlign = cairo_dock_get_double_key_value (pKeyFile, "Position", "alignment", &bFlushConfFileNeeded, 0.5, NULL, NULL);
 	
-	pPosition->bUseXinerama = cairo_dock_get_boolean_key_value (pKeyFile, "Position", "xinerama", &bFlushConfFileNeeded, 0, NULL, NULL);
-	if (pPosition->bUseXinerama && ! cairo_dock_xinerama_is_available ())
+	pPosition->iNumScreen = cairo_dock_get_integer_key_value (pKeyFile, "Position", "num_screen", &bFlushConfFileNeeded, GLDI_DEFAULT_SCREEN, NULL, NULL);  // Note: if this screen doesn't exist at this time, we keep this number anyway, in case it is plugged later. Until then, it will point on the X screen.
+	if (g_key_file_has_key (pKeyFile, "Position", "xinerama", NULL))  // "xinerama" and "num screen" old keys
 	{
-		cd_warning ("Sorry but either your X server does not have the Xinerama extension, or your version of Cairo-Dock was not built with the support of Xinerama.\n You can't place the dock on a particular screen");
-		pPosition->bUseXinerama = FALSE;
+		if (g_key_file_get_boolean (pKeyFile," Position", "xinerama", NULL))  // xinerama was used -> set num-screen back
+		{
+			pPosition->iNumScreen = g_key_file_get_integer (pKeyFile, "Position", "num screen", NULL); // "num screen" was the old key
+			g_key_file_set_integer (pKeyFile, "Position", "num_screen", pPosition->iNumScreen);
+		}
 	}
-	if (pPosition->bUseXinerama)
-		pPosition->iNumScreen = cairo_dock_get_integer_key_value (pKeyFile, "Position", "num screen", &bFlushConfFileNeeded, 0, NULL, NULL);
 	
 	//\____________________ Visibilite
 	int iVisibility = cairo_dock_get_integer_key_value (pKeyFile, "Accessibility", "visibility", &bFlushConfFileNeeded, -1, NULL, NULL);  // -1 pour pouvoir intercepter le cas ou la cle n'existe pas.
@@ -1546,8 +1543,6 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 	}
 	
 	//\____________________ Autres parametres.
-	pAccessibility->iMaxAuthorizedWidth = cairo_dock_get_integer_key_value (pKeyFile, "Accessibility", "max_authorized_width", &bFlushConfFileNeeded, 0, "Position", NULL);  // obsolete, cache en conf.
-	
 	double fSensitivity = cairo_dock_get_double_key_value (pKeyFile, "Accessibility", "edge sensitivity", &bFlushConfFileNeeded, -1, NULL, NULL);  // replace "unhide delay"
 	if (fSensitivity < 0)  // old param
 	{
@@ -1557,9 +1552,6 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 	}
 	pAccessibility->iUnhideDockDelay = fSensitivity * 1000;  // so we decreased the old delay by 1.5, since we handle mouse movements better.
 	
-	pAccessibility->bAutoHideOnFullScreen = cairo_dock_get_boolean_key_value (pKeyFile, "Accessibility", "auto quick hide", &bFlushConfFileNeeded, FALSE, "TaskBar", NULL);
-	//pAccessibility->bAutoHideOnFullScreen = FALSE;
-	
 	//\____________________ sous-docks.
 	pAccessibility->iLeaveSubDockDelay = cairo_dock_get_integer_key_value (pKeyFile, "Accessibility", "leaving delay", &bFlushConfFileNeeded, 330, "System", NULL);
 	pAccessibility->iShowSubDockDelay = cairo_dock_get_integer_key_value (pKeyFile, "Accessibility", "show delay", &bFlushConfFileNeeded, 300, "System", NULL);
@@ -1632,11 +1624,7 @@ static void load (void)
 		g_pMainDock->iGapX = myDocksParam.iGapX;
 		g_pMainDock->iGapY = myDocksParam.iGapY;
 		g_pMainDock->fAlign = myDocksParam.fAlign;
-		if (myDocksParam.bUseXinerama)
-		{
-			g_pMainDock->iNumScreen = myDocksParam.iNumScreen;
-			cairo_dock_get_screen_offsets (myDocksParam.iNumScreen, &g_pMainDock->iScreenOffsetX, &g_pMainDock->iScreenOffsetY);
-		}
+		g_pMainDock->iNumScreen = myDocksParam.iNumScreen;
 		g_pMainDock->bExtendedMode = myDocksParam.bExtendedMode;
 		
 		cairo_dock_set_dock_orientation (g_pMainDock, myDocksParam.iScreenBorder);
@@ -1704,24 +1692,9 @@ static void reload (CairoDocksParam *pPrevDocksParam, CairoDocksParam *pDocksPar
 	cairo_dock_foreach_root_docks ((GFunc)_reload_bg, NULL);
 	
 	// position
-	if (pPosition->bUseXinerama)
-	{
-		pDock->iNumScreen = pPosition->iNumScreen;
-		cairo_dock_get_screen_offsets (pPosition->iNumScreen, &pDock->iScreenOffsetX, &pDock->iScreenOffsetY);
-	}
-	else  // on n'utilise pas Xinerama.
-	{
-		pDock->iNumScreen = pDock->iScreenOffsetX = pDock->iScreenOffsetY = 0;
-		if (pPrevPosition->bUseXinerama)  // mais on l'utilisait avant, il faut donc recuperer les dimensions de l'ecran.
-		{
-			g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL] = g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
-			g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] = g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
-			g_desktopGeometry.iScreenWidth[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL];
-			g_desktopGeometry.iScreenHeight[CAIRO_DOCK_VERTICAL] = g_desktopGeometry.iScreenWidth[CAIRO_DOCK_HORIZONTAL];
-		}
-	}
+	pDock->iNumScreen = pPosition->iNumScreen;
 	
-	if (pPosition->bUseXinerama != pPrevPosition->bUseXinerama)
+	if (pPosition->iNumScreen != pPrevPosition->iNumScreen)
 	{
 		cairo_dock_reposition_root_docks (TRUE);  // on replace tous les docks racines sauf le main dock, puisque c'est fait apres.
 	}
@@ -1730,14 +1703,25 @@ static void reload (CairoDocksParam *pPrevDocksParam, CairoDocksParam *pDocksPar
 	if (pPosition->iScreenBorder != pPrevPosition->iScreenBorder)
 	{
 		cairo_dock_set_dock_orientation (pDock, pPosition->iScreenBorder);
-		_cairo_dock_draw_one_subdock_icon (NULL, g_pMainDock, NULL);  // container-icons may be drawn differently according to the orientation (ex.: box).
+		cairo_dock_reload_buffers_in_all_docks (TRUE);  // icons may have a different width and height, so changing the orientation will affect them.  also, container-icons may be drawn differently according to the orientation (ex.: box).
+		///_cairo_dock_draw_one_subdock_icon (NULL, g_pMainDock, NULL);  // container-icons may be drawn differently according to the orientation (ex.: box).
 	}
 	pDock->bExtendedMode = pBackground->bExtendedMode;
-	cairo_dock_update_dock_size (pDock);  // si l'ecran ou l'orientation a change, la taille max a change aussi.
+	
+	if (pPosition->iNumScreen != pPrevPosition->iNumScreen
+	|| pPosition->iScreenBorder != pPrevPosition->iScreenBorder)  // if the orientation or the screen has changed, the available size may have changed too
+	{
+		cairo_dock_update_dock_size (pDock);
+	}
 	
 	pDock->iGapX = pPosition->iGapX;
 	pDock->iGapY = pPosition->iGapY;
 	pDock->fAlign = pPosition->fAlign;
+	if (pPosition->fAlign != pPrevPosition->fAlign)
+	{
+		cairo_dock_update_dock_size (pDock);
+		cairo_dock_move_resize_dock (pDock);
+	}
 	cairo_dock_calculate_dock_icons (pDock);
 	cairo_dock_move_resize_dock (pDock);
 	if (bWasHorizontal != pDock->container.bIsHorizontal)
