@@ -171,7 +171,7 @@ do_ungrab_key (CairoKeyBinding *binding)
 }
 
 static GdkFilterReturn
-filter_func (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data)
+filter_func (GdkXEvent *gdk_xevent, GdkEvent *event, G_GNUC_UNUSED gpointer data)
 {
 	GdkFilterReturn return_val = GDK_FILTER_CONTINUE;
 	XEvent *xevent = (XEvent *) gdk_xevent;
@@ -222,7 +222,7 @@ filter_func (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data)
 }
 
 static void
-on_keymap_changed (GdkKeymap *map)
+on_keymap_changed (G_GNUC_UNUSED GdkKeymap *map)
 {
 	GdkKeymap *keymap = gdk_keymap_get_default ();
 	GSList *iter;
@@ -255,7 +255,6 @@ cd_keybinder_bind (const gchar *keystring,
 	gpointer user_data)
 {
 	CairoKeyBinding *binding;
-	gboolean success;
 	cd_debug ("%s (%s)", __func__, keystring);
 	
 	// register the new shortkey
@@ -318,7 +317,7 @@ cd_keybinder_unbind (CairoKeyBinding *binding)
 		do_ungrab_key (binding);
 	
 	// remove it from the list and destroy it
-	cd_debug (" --- remove key binding '%s'\n", binding->keystring);
+	cd_debug (" --- remove key binding '%s'", binding->keystring);
 	s_pKeyBindings = g_slist_delete_link (s_pKeyBindings, iter);
 	
 	cairo_dock_notify_on_object (&myShortkeysMgr, NOTIFICATION_SHORTKEY_REMOVED, binding);
@@ -439,7 +438,7 @@ static void init (void)
 	{
 		CairoKeyBinding *binding = (CairoKeyBinding *) iter->data;
 		
-		cd_debug (" --- remove key binding '%s'\n", binding->keystring);
+		cd_debug (" --- remove key binding '%s'", binding->keystring);
 		if (binding->bSuccess)
 		{
 			do_ungrab_key (binding);
