@@ -17,23 +17,18 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <string.h>
 #include <math.h>
-#include <stdlib.h>
-
-#include <X11/extensions/Xrender.h>
+#include <GL/gl.h>
+#include <GL/glu.h>  // gluLookAt
 #include <GL/glx.h>
-#include <GL/glxext.h>
-#include <GL/glu.h>
 #include <gdk/gdkx.h>
+#include <X11/extensions/Xrender.h>  // XRenderFindVisualFormat
 
 #include "cairo-dock-log.h"
-#include "cairo-dock-icon-facility.h"
-#include "cairo-dock-dock-factory.h"
-#include "cairo-dock-desklet-factory.h"  // cairo_dock_begin_draw_icon
-#include "cairo-dock-image-buffer.h"
+#include "cairo-dock-icon-facility.h"  // cairo_dock_get_icon_extent
 #include "cairo-dock-draw-opengl.h"
-#include "cairo-dock-X-manager.h"
+#include "cairo-dock-X-manager.h"  // desktop dimensions
+
 #include "cairo-dock-opengl.h"
 
 // public (manager, config, data)
@@ -42,7 +37,6 @@ gboolean g_bUseOpenGL = FALSE;
 
 // dependancies
 extern CairoContainer *g_pPrimaryContainer;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern CairoDockDesktopBackground *g_pFakeTransparencyDesktopBg;
 extern gboolean g_bEasterEggs;
 
@@ -285,16 +279,10 @@ gboolean cairo_dock_initialize_opengl_backend (gboolean bForceOpenGL)  // taken
 	g_return_val_if_fail (g_openglConfig.pGdkVisual != NULL, FALSE);
 	#endif
 	g_openglConfig.pVisInfo = pVisInfo;
+	/** Note: this is where we can't use gtkglext: gdk_x11_gl_config_new_from_visualid() sets a new colormap on the root window, and Qt doesn't like that
+	cf https://bugzilla.redhat.com/show_bug.cgi?id=440340
+	which would force us to do a XDeleteProperty ( dpy, DefaultRootWindow (dpy), XInternAtom (dpy, "RGB_DEFAULT_MAP", 0) ) */
 	
-	/**
-	/// The function below sets a new colormap on the root window, and Qt doesn't like that !...
-	/// link with https://bugzilla.redhat.com/show_bug.cgi?id=440340 ?
-	g_openglConfig.pGlConfig = gdk_x11_gl_config_new_from_visualid (pVisInfo->visualid);
-	/// as a workaround, we remove this colormap.
-	Display *dpy = gdk_x11_display_get_xdisplay (gdk_display_get_default ());
-	XDeleteProperty ( dpy, DefaultRootWindow (dpy), XInternAtom (dpy, "RGB_DEFAULT_MAP", 0) ); // (XA_RGB_DEFAULT_MAP)
-	XFree (pVisInfo);
-	g_return_val_if_fail (g_openglConfig.pGlConfig != NULL, FALSE);*/
 	g_bUseOpenGL = TRUE;
 	
 	//\_________________ on verifier les capacites des textures.
@@ -317,312 +305,6 @@ void cairo_dock_force_indirect_rendering (void)
 }
 
 
-void cairo_dock_create_icon_fbo (void)  // it has been found that you get a speed boost if your textures is the same size and you use 1 FBO for them. => c'est le cas general dans le dock. Du coup on est gagnant a ne faire qu'un seul FBO pour toutes les icones.
-{
-	if (! g_openglConfig.bFboAvailable)
-		return ;
-	g_return_if_fail (g_openglConfig.iFboId == 0);
-	
-	glGenFramebuffersEXT(1, &g_openglConfig.iFboId);
-	
-	int iWidth = myIconsParam.iIconWidth;
-	int iHeight = myIconsParam.iIconHeight;
-	
-	iWidth *= (1 + myIconsParam.fAmplitude);
-	iHeight *= (1 + myIconsParam.fAmplitude);
-	g_openglConfig.iRedirectedTexture = cairo_dock_create_texture_from_raw_data (NULL, iWidth, iHeight);
-}
-
-void cairo_dock_destroy_icon_fbo (void)
-{
-	if (g_openglConfig.iFboId == 0)
-		return;
-	glDeleteFramebuffersEXT (1, &g_openglConfig.iFboId);
-	g_openglConfig.iFboId = 0;
-	
-	_cairo_dock_delete_texture (g_openglConfig.iRedirectedTexture);
-	g_openglConfig.iRedirectedTexture = 0;
-}
-
-
-gboolean cairo_dock_begin_draw_icon (Icon *pIcon, CairoContainer *pContainer, gint iRenderingMode)
-{
-	//g_print ("%s (%s, %d)\n", __func__, pIcon->cName, iRenderingMode);
-	int iWidth, iHeight;
-	/// TODO: test without FBO and dock when iRenderingMode == 2
-	if (CAIRO_DOCK_IS_DESKLET (pContainer))
-	{
-		if (! gldi_glx_make_current (pContainer))
-		{
-			pIcon->bDamaged = TRUE;
-			return FALSE;
-		}
-		iWidth = pContainer->iWidth;
-		iHeight = pContainer->iHeight;
-		glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-	}
-	else if (g_openglConfig.iFboId != 0)
-	{
-		// on attache la texture au FBO.
-		if (pContainer->iWidth == 1 && pContainer->iHeight == 1)  // container not yet fully resized
-		{
-			pIcon->bDamaged = TRUE;
-			return FALSE;
-		}
-		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
-		if (pContainer == NULL)
-			pContainer = g_pPrimaryContainer;
-		if (! gldi_glx_make_current (pContainer))
-		{
-			cd_warning ("couldn't set the opengl context");
-			pIcon->bDamaged = TRUE;
-			return FALSE;
-		}
-		glBindFramebufferEXT (GL_FRAMEBUFFER_EXT, g_openglConfig.iFboId);  // on redirige sur notre FBO.
-		g_openglConfig.bRedirected = (iRenderingMode == 2);
-		glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-			GL_COLOR_ATTACHMENT0_EXT,
-			GL_TEXTURE_2D,
-			g_openglConfig.bRedirected ? g_openglConfig.iRedirectedTexture : pIcon->iIconTexture,
-			0);  // attach the texture to FBO color attachment point.
-		
-		GLenum status = glCheckFramebufferStatusEXT (GL_FRAMEBUFFER_EXT);
-		if (status != GL_FRAMEBUFFER_COMPLETE_EXT)
-		{
-			cd_warning ("FBO not ready for %s (tex:%d)", pIcon->cName, pIcon->iIconTexture);
-			glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);  // switch back to window-system-provided framebuffer
-			glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-				GL_COLOR_ATTACHMENT0_EXT,
-				GL_TEXTURE_2D,
-				0,
-				0);
-			pIcon->bDamaged = TRUE;
-			return FALSE;
-		}
-		
-		if (iRenderingMode != 1)
-			glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-	}
-	else
-		return FALSE;
-	
-	if (pContainer->bPerspectiveView)
-	{
-		cairo_dock_set_ortho_view (pContainer);
-		g_openglConfig.bSetPerspective = TRUE;
-	}
-	else
-	{
-		cairo_dock_set_ortho_view (pContainer);  // au demarrage, le contexte n'a pas encore de vue.
-		glLoadIdentity ();
-		glTranslatef (iWidth/2, iHeight/2, - iHeight/2);
-	}
-	
-	glColor4f(1., 1., 1., 1.);
-	
-	glScalef (1., -1., 1.);
-	
-	return TRUE;
-}
-
-void cairo_dock_end_draw_icon (Icon *pIcon, CairoContainer *pContainer)
-{
-	g_return_if_fail (pIcon->iIconTexture != 0);
-	
-	if (CAIRO_DOCK_IS_DESKLET (pContainer))
-	{
-		// copie dans notre texture
-		glEnable (GL_TEXTURE_2D);
-		glBindTexture (GL_TEXTURE_2D, pIcon->iIconTexture);
-		glTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-		glEnable(GL_BLEND);
-		glBlendFunc (GL_ZERO, GL_ONE);
-		glColor4f(1., 1., 1., 1.);
-		
-		int iWidth, iHeight;  // taille de la texture
-		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
-		int x = (pContainer->iWidth - iWidth)/2;
-		int y = (pContainer->iHeight - iHeight)/2;
-		glCopyTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, x, y, iWidth, iHeight, 0);  // target, num mipmap, format, x,y, w,h, border.
-		
-		glDisable (GL_TEXTURE_2D);
-		glDisable (GL_BLEND);
-	}
-	else if (g_openglConfig.iFboId != 0)
-	{
-		if (g_openglConfig.bRedirected)  // copie dans notre texture
-		{
-			glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-				GL_COLOR_ATTACHMENT0_EXT,
-				GL_TEXTURE_2D,
-				pIcon->iIconTexture,
-				0);  // maintenant on dessine dans la texture de l'icone.
-			_cairo_dock_enable_texture ();
-			_cairo_dock_set_blend_source ();
-			
-			int iWidth, iHeight;  // taille de la texture
-			cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
-			
-			glLoadIdentity ();
-			glTranslatef (iWidth/2, iHeight/2, - iHeight/2);
-			_cairo_dock_apply_texture_at_size_with_alpha (g_openglConfig.iRedirectedTexture, iWidth, iHeight, 1.);
-			
-			_cairo_dock_disable_texture ();
-			g_openglConfig.bRedirected = FALSE;
-		}
-		glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);  // switch back to window-system-provided framebuffer
-		glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-			GL_COLOR_ATTACHMENT0_EXT,
-			GL_TEXTURE_2D,
-			0,
-			0);  // on detache la texture (precaution).
-		//glGenerateMipmapEXT(GL_TEXTURE_2D);  // si on utilise les mipmaps, il faut les generer explicitement avec les FBO.
-	}
-	
-	if (pContainer && g_openglConfig.bSetPerspective)
-	{
-		cairo_dock_set_perspective_view (pContainer);
-		g_openglConfig.bSetPerspective = FALSE;
-	}
-}
-
-gboolean cairo_dock_begin_draw_image_buffer (CairoDockImageBuffer *pImage, CairoContainer *pContainer, gint iRenderingMode)
-{
-	//g_print ("%s (%s, %d)\n", __func__, pIcon->cName, iRenderingMode);
-	int iWidth, iHeight;
-	/// TODO: test without FBO and dock when iRenderingMode == 2
-	if (CAIRO_DOCK_IS_DESKLET (pContainer))
-	{
-		if (! gldi_glx_make_current (pContainer))
-		{
-			return FALSE;
-		}
-		iWidth = pContainer->iWidth;
-		iHeight = pContainer->iHeight;
-		glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-	}
-	else if (g_openglConfig.iFboId != 0)
-	{
-		// on attache la texture au FBO.
-		if (pContainer->iWidth == 1 && pContainer->iHeight == 1)  // container not yet fully resized
-		{
-			return FALSE;
-		}
-		iWidth = pImage->iWidth, iHeight = pImage->iHeight;
-		if (pContainer == NULL)
-			pContainer = g_pPrimaryContainer;
-		if (! gldi_glx_make_current (pContainer))
-		{
-			cd_warning ("couldn't set the opengl context");
-			return FALSE;
-		}
-		glBindFramebufferEXT (GL_FRAMEBUFFER_EXT, g_openglConfig.iFboId);  // on redirige sur notre FBO.
-		g_openglConfig.bRedirected = (iRenderingMode == 2);
-		glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-			GL_COLOR_ATTACHMENT0_EXT,
-			GL_TEXTURE_2D,
-			g_openglConfig.bRedirected ? g_openglConfig.iRedirectedTexture : pImage->iTexture,
-			0);  // attach the texture to FBO color attachment point.
-		
-		GLenum status = glCheckFramebufferStatusEXT (GL_FRAMEBUFFER_EXT);
-		if (status != GL_FRAMEBUFFER_COMPLETE_EXT)
-		{
-			cd_warning ("FBO not ready (tex:%d)", pImage->iTexture);
-			glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);  // switch back to window-system-provided framebuffer
-			glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-				GL_COLOR_ATTACHMENT0_EXT,
-				GL_TEXTURE_2D,
-				0,
-				0);
-			return FALSE;
-		}
-		
-		if (iRenderingMode != 1)
-			glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-	}
-	else
-		return FALSE;
-	
-	if (pContainer->bPerspectiveView)
-	{
-		cairo_dock_set_ortho_view (pContainer);
-		g_openglConfig.bSetPerspective = TRUE;
-	}
-	else
-	{
-		cairo_dock_set_ortho_view (pContainer);  // au demarrage, le contexte n'a pas encore de vue.
-		glLoadIdentity ();
-		glTranslatef (iWidth/2, iHeight/2, - iHeight/2);
-	}
-	
-	glColor4f(1., 1., 1., 1.);
-	
-	glScalef (1., -1., 1.);
-	
-	return TRUE;
-}
-
-void cairo_dock_end_draw_image_buffer (CairoDockImageBuffer *pImage, CairoContainer *pContainer)
-{
-	g_return_if_fail (pImage->iTexture != 0);
-	
-	if (CAIRO_DOCK_IS_DESKLET (pContainer))
-	{
-		// copie dans notre texture
-		glEnable (GL_TEXTURE_2D);
-		glBindTexture (GL_TEXTURE_2D, pImage->iTexture);
-		glTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-		glEnable(GL_BLEND);
-		glBlendFunc (GL_ZERO, GL_ONE);
-		glColor4f(1., 1., 1., 1.);
-		
-		int iWidth, iHeight;  // taille de la texture
-		iWidth = pImage->iWidth, iHeight = pImage->iHeight;
-		int x = (pContainer->iWidth - iWidth)/2;
-		int y = (pContainer->iHeight - iHeight)/2;
-		glCopyTexImage2D (GL_TEXTURE_2D, 0, GL_RGBA, x, y, iWidth, iHeight, 0);  // target, num mipmap, format, x,y, w,h, border.
-		
-		glDisable (GL_TEXTURE_2D);
-		glDisable (GL_BLEND);
-	}
-	else if (g_openglConfig.iFboId != 0)
-	{
-		if (g_openglConfig.bRedirected)  // copie dans notre texture
-		{
-			glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-				GL_COLOR_ATTACHMENT0_EXT,
-				GL_TEXTURE_2D,
-				pImage->iTexture,
-				0);  // maintenant on dessine dans la texture de l'icone.
-			_cairo_dock_enable_texture ();
-			_cairo_dock_set_blend_source ();
-			
-			int iWidth, iHeight;  // taille de la texture
-			iWidth = pImage->iWidth, iHeight = pImage->iHeight;
-			
-			glLoadIdentity ();
-			glTranslatef (iWidth/2, iHeight/2, - iHeight/2);
-			_cairo_dock_apply_texture_at_size_with_alpha (g_openglConfig.iRedirectedTexture, iWidth, iHeight, 1.);
-			
-			_cairo_dock_disable_texture ();
-			g_openglConfig.bRedirected = FALSE;
-		}
-		glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);  // switch back to window-system-provided framebuffer
-		glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT,
-			GL_COLOR_ATTACHMENT0_EXT,
-			GL_TEXTURE_2D,
-			0,
-			0);  // on detache la texture (precaution).
-		//glGenerateMipmapEXT(GL_TEXTURE_2D);  // si on utilise les mipmaps, il faut les generer explicitement avec les FBO.
-	}
-	
-	if (pContainer && g_openglConfig.bSetPerspective)
-	{
-		cairo_dock_set_perspective_view (pContainer);
-		g_openglConfig.bSetPerspective = FALSE;
-	}
-}
-
 
 static inline void _cairo_dock_set_perspective_view (int iWidth, int iHeight)
 {
@@ -717,8 +399,8 @@ void gldi_glx_apply_desktop_background (CairoContainer *pContainer)
 	glBindTexture (GL_TEXTURE_2D, g_pFakeTransparencyDesktopBg->iTexture);
 	
 	double x, y, w, h, W, H;
-	W = g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
-	H = g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+	W = gldi_get_desktop_width();
+	H = gldi_get_desktop_height();
 	if (pContainer->bIsHorizontal)
 	{
 		w = pContainer->iWidth;
